@@ -23,37 +23,103 @@ import gzip
 import os
 import re
 import shutil
+import textwrap
 
 import oz.GuestFSManager
 import oz.Linux
 import oz.OzException
 import oz.ozutil
 
+
+class DebianConfiguration(object):
+    """
+    Configuration class for Debian installation.
+    """
+    def __init__(self, need_auto_direct, need_auto_iso, default_netdev,
+                 default_diskbus):
+        self._need_auto_direct = need_auto_direct
+        self._need_auto_iso = need_auto_iso
+        self._default_netdev = default_netdev
+        self._default_diskbus = default_diskbus
+
+    @property
+    def need_auto_direct(self):
+        """
+        Property method for whether this version of Debian needs 'auto' on the
+        command-line for direct installs.
+        """
+        return self._need_auto_direct
+
+    @property
+    def need_auto_iso(self):
+        """
+        Property method for whether this version of Debian needs 'auto' on the
+        command-line for ISO installs.
+        """
+        return self._need_auto_iso
+
+    @property
+    def default_netdev(self):
+        """
+        Property method for the default netdev for this version of Debian.
+        """
+        return self._default_netdev
+
+    @property
+    def default_diskbus(self):
+        """
+        Property method for the default diskbus for this version of Debian.
+        """
+        return self._default_diskbus
+
+
+version_to_config = {
+    '9': DebianConfiguration(need_auto_direct=False, need_auto_iso=True,
+                             default_netdev='virtio', default_diskbus='virtio'),
+    '8': DebianConfiguration(need_auto_direct=False, need_auto_iso=True,
+                             default_netdev='virtio', default_diskbus='virtio'),
+    '7': DebianConfiguration(need_auto_direct=True, need_auto_iso=True,
+                             default_netdev='virtio', default_diskbus='virtio'),
+    '6': DebianConfiguration(need_auto_direct=False, need_auto_iso=False,
+                             default_netdev='virtio', default_diskbus='virtio'),
+    '5': DebianConfiguration(need_auto_direct=False, need_auto_iso=False,
+                             default_netdev='virtio', default_diskbus='virtio'),
+}
+
+
 class DebianGuest(oz.Linux.LinuxCDGuest):
     """
-    Class for Debian 5, 6, 7 and 8 installation.
+    Class for Debian 5, 6, 7, 8, and 9 installation.
     """
     def __init__(self, tdl, config, auto, output_disk, netdev, diskbus,
                  macaddress):
+        self.config = version_to_config[tdl.update]
+
+        if netdev is None:
+            netdev = self.config.default_netdev
+        if diskbus is None:
+            diskbus = self.config.default_diskbus
         oz.Linux.LinuxCDGuest.__init__(self, tdl, config, auto, output_disk,
                                        netdev, diskbus, True, True, macaddress)
 
         self.crond_was_active = False
         self.sshd_was_active = False
-        self.sshd_config = \
-"""SyslogFacility AUTHPRIV
-PasswordAuthentication yes
-ChallengeResponseAuthentication no
-GSSAPIAuthentication yes
-GSSAPICleanupCredentials yes
-UsePAM yes
-AcceptEnv LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES
-AcceptEnv LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT
-AcceptEnv LC_IDENTIFICATION LC_ALL LANGUAGE
-AcceptEnv XMODIFIERS
-X11Forwarding yes
-Subsystem       sftp    /usr/libexec/openssh/sftp-server
-"""
+        self.sshd_config = textwrap.dedent(
+            """\
+            SyslogFacility AUTHPRIV
+            PasswordAuthentication yes
+            ChallengeResponseAuthentication no
+            GSSAPIAuthentication yes
+            GSSAPICleanupCredentials yes
+            UsePAM yes
+            AcceptEnv LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES
+            AcceptEnv LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT
+            AcceptEnv LC_IDENTIFICATION LC_ALL LANGUAGE
+            AcceptEnv XMODIFIERS
+            X11Forwarding yes
+            Subsystem       sftp    /usr/libexec/openssh/sftp-server
+            """
+        )
 
         self.tunnels = {}
 
@@ -73,13 +139,6 @@ Subsystem       sftp    /usr/libexec/openssh/sftp-server
         self.initrdcache = os.path.join(self.data_dir, "kernels",
                                         self.tdl.distro + self.tdl.update + self.tdl.arch + "-ramdisk")
 
-        extra = ""
-        if self.tdl.update in ["7"]:
-            extra = "auto=true "
-        self.cmdline = "priority=critical " + extra + "locale=en_US"
-
-        self.reboots = 0
-
     def _copy_preseed(self, outname):
         """
         Method to copy and modify an Debian style preseed file.
@@ -96,8 +155,7 @@ Subsystem       sftp    /usr/libexec/openssh/sftp-server
                     return 'd-i passwd/root-password password ' + self.rootpw + '\n'
                 elif re.match('d-i passwd/root-password-again password', line):
                     return 'd-i passwd/root-password-again password ' + self.rootpw + '\n'
-                else:
-                    return line
+                return line
 
             oz.ozutil.copy_modify_file(self.auto, outname, _preseed_sub)
         else:
@@ -122,20 +180,23 @@ Subsystem       sftp    /usr/libexec/openssh/sftp-server
         self.log.debug("Modifying isolinux.cfg")
         isolinuxcfg = os.path.join(self.iso_contents, "isolinux", "isolinux.cfg")
         extra = ""
-        if self.tdl.update in ["7", "8"]:
+        if self.config.need_auto_iso:
             extra = "auto=true "
 
         with open(isolinuxcfg, 'w') as f:
-            f.write("""\
-default customiso
-timeout 1
-prompt 0
-label customiso
-  menu label ^Customiso
-  menu default
-  kernel %s/vmlinuz
-  append file=/cdrom/preseed/customiso.seed %sdebian-installer/locale=en_US console-setup/layoutcode=us netcfg/choose_interface=auto priority=critical initrd=%s/initrd.gz --
-""" % (installdir, extra, installdir))
+            f.write(textwrap.dedent(
+                """\
+                default customiso
+                timeout 1
+                prompt 0
+                label customiso
+                  menu label ^Customiso
+                  menu default
+                  kernel %s/vmlinuz
+                  append file=/cdrom/preseed/customiso.seed %sdebian-installer/\
+locale=en_US console-setup/layoutcode=us netcfg/choose_interface=auto priority=\
+critical initrd=%s/initrd.gz --
+                """ % (installdir, extra, installdir)))
 
     def get_auto_path(self):
         autoname = self.tdl.distro + self.tdl.update + ".auto"
@@ -163,8 +224,12 @@ label customiso
         """
         Method to run the operating system installation.
         """
-        return self._do_install(timeout, force, self.reboots, self.kernelfname,
-                                self.initrdfname, self.cmdline)
+        extra = ""
+        if self.config.need_auto_direct:
+            extra = "auto=true "
+        cmdline = "priority=critical " + extra + "locale=en_US"
+        return self._do_install(timeout, force, 0, self.kernelfname,
+                                self.initrdfname, cmdline)
 
     def _get_service_runlevel_link(self, g_handle, service):
         """
@@ -179,7 +244,7 @@ label customiso
             if re.match('# chkconfig:', line):
                 try:
                     startlevel = line.split(':')[1].split()[1]
-                except:
+                except Exception:
                     pass
                 break
 
@@ -392,7 +457,7 @@ label customiso
         self.log.debug("Installing additional repository files")
 
         for repo in list(self.tdl.repositories.values()):
-            self.guest_execute_command(guestaddr, "echo '%s' > /etc/apt/sources.list.d/%s" % (repo.url.strip('\'"'), repo.name + "list"))
+            self.guest_execute_command(guestaddr, "echo '%s' > /etc/apt/sources.list.d/%s" % (repo.url.strip('\'"'), repo.name + ".list"))
             self.guest_execute_command(guestaddr, "apt-get update")
 
     def _install_packages(self, guestaddr, packstr):
@@ -405,9 +470,9 @@ label customiso
         XML.
         """
         self.log.debug("Generating ICICLE")
-        stdout, stderr, retcode = self.guest_execute_command(guestaddr,
-                                                             'dpkg --get-selections',
-                                                             timeout=30)
+        stdout, stderr_unused, retcode_unused = self.guest_execute_command(guestaddr,
+                                                                           'dpkg --get-selections',
+                                                                           timeout=30)
 
         # the data we get back from dpkg is in the form of:
         #
@@ -511,7 +576,7 @@ label customiso
         initrd = None
         try:
             (kernel, initrd) = self._get_kernel_from_txt_cfg(fetchurl)
-        except:
+        except Exception:
             pass
 
         if kernel is None:
@@ -562,6 +627,11 @@ label customiso
             os.unlink(self.kernelfname)
             raise
 
+    def _remove_repos(self, guestaddr):
+        # FIXME: until we switch over to doing repository add by hand (instead
+        # of using add-apt-repository), we can't really reliably implement this
+        pass
+
     def generate_install_media(self, force_download=False,
                                customize_or_icicle=False):
         """
@@ -600,14 +670,14 @@ label customiso
         for fname in [self.output_iso, self.initrdfname, self.kernelfname]:
             try:
                 os.unlink(fname)
-            except:
+            except Exception:
                 pass
 
         if not self.cache_original_media:
             for fname in [self.orig_iso, self.kernelcache, self.initrdcache]:
                 try:
                     os.unlink(fname)
-                except:
+                except Exception:
                     pass
 
 
@@ -616,16 +686,13 @@ def get_class(tdl, config, auto, output_disk=None, netdev=None, diskbus=None,
     """
     Factory method for Debian installs.
     """
-    if tdl.update in ["5", "6", "7", "8"]:
-        if netdev is None:
-            netdev = 'virtio'
-        if diskbus is None:
-            diskbus = 'virtio'
+    if tdl.update in version_to_config.keys():
         return DebianGuest(tdl, config, auto, output_disk, netdev, diskbus,
                            macaddress)
 
+
 def get_supported_string():
     """
     Return supported versions as a string.
     """
-    return "Debian: 5, 6, 7, 8"
+    return "Debian: " + ", ".join(sorted(version_to_config.keys()))
