@@ -1,5 +1,5 @@
 # Copyright (C) 2010,2011  Chris Lalancette <clalance@redhat.com>
-# Copyright (C) 2012-2017  Chris Lalancette <clalancette@gmail.com>
+# Copyright (C) 2012-2018  Chris Lalancette <clalancette@gmail.com>
 
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -19,33 +19,37 @@
 Main class for guest installation
 """
 
-import uuid
+import base64
+import errno
+import hashlib
+import logging
 import os
-import subprocess
+import re
 import shutil
+import socket
+import stat
+import struct
+import subprocess
+import tempfile
 import time
 try:
     import urllib.parse as urlparse
 except ImportError:
     import urlparse
-import stat
-import logging
-import socket
-import struct
-import tempfile
-import base64
-import hashlib
-import errno
-import re
+import uuid
 
-import guestfs
-import libvirt
-import lxml.etree
 import M2Crypto
 
+import guestfs
+
+import libvirt
+
+import lxml.etree
+
 import oz.GuestFSManager
-import oz.ozutil
 import oz.OzException
+import oz.ozutil
+
 
 class Guest(object):
     """
@@ -89,13 +93,13 @@ class Guest(object):
 
                 forward = doc.xpath('/network/forward')
                 if len(forward) != 1:
-                    self.log.warn("Libvirt network without a forward element, skipping")
+                    self.log.warning("Libvirt network without a forward element, skipping")
                     continue
 
                 if forward[0].get('mode') == 'nat':
                     ips = doc.xpath('/network/ip')
-                    if len(ips) == 0:
-                        self.log.warn("Libvirt network without an IP, skipping")
+                    if not ips:
+                        self.log.warning("Libvirt network without an IP, skipping")
                         continue
                     for ip in ips:
                         family = ip.get("family")
@@ -131,7 +135,7 @@ class Guest(object):
         # for backwards compatibility
         self.name = self.tdl.name
 
-        if not self.tdl.arch in ["i386", "x86_64", "ppc64", "ppc64le", "aarch64", "armv7l"]:
+        if self.tdl.arch not in ["i386", "x86_64", "ppc64", "ppc64le", "aarch64", "armv7l", "s390x"]:
             raise oz.OzException.OzException("Unsupported guest arch " + self.tdl.arch)
 
         if os.uname()[4] in ["i386", "i586", "i686"] and self.tdl.arch == "x86_64":
@@ -415,16 +419,23 @@ class Guest(object):
         """
         Method to generate the serial portion of the libvirt XML.
         """
-        serial = oz.ozutil.lxml_subelement(devices, "serial", None, {'type':'tcp'})
+        serial = oz.ozutil.lxml_subelement(devices, "serial", None, {'type': 'tcp'})
         oz.ozutil.lxml_subelement(serial, "source", None,
-                                  {'mode':'bind', 'host':'127.0.0.1', 'service':str(self.listen_port)})
-        oz.ozutil.lxml_subelement(serial, "protocol", None, {'type':'raw'})
-        oz.ozutil.lxml_subelement(serial, "target", None, {'port':'1'})
+                                  {'mode': 'bind', 'host': '127.0.0.1', 'service': str(self.listen_port)})
+        oz.ozutil.lxml_subelement(serial, "protocol", None, {'type': 'raw'})
+        target = oz.ozutil.lxml_subelement(serial, "target", None, {'port': '1'})
+        if self.tdl.arch == 's390x':
+            # use a different console, as sclp can be used as most once
+            target.set('type', 'sclp-serial')
+            oz.ozutil.lxml_subelement(target, "model", None, {'name': 'sclplmconsole'})
 
     def _generate_virtio_channel(self, devices, name):
+        """
+        Method to generate libvirt XML for a virtio channel.
+        """
         virtio = oz.ozutil.lxml_subelement(devices, "channel", None, {'type': 'tcp'})
         oz.ozutil.lxml_subelement(virtio, "source", None,
-                                  {'mode':'bind', 'host':'127.0.0.1', 'service':str(self.console_listen_port)})
+                                  {'mode': 'bind', 'host': '127.0.0.1', 'service': str(self.console_listen_port)})
         oz.ozutil.lxml_subelement(virtio, "target", None, {"type": "virtio", "name": name})
 
     def _generate_xml(self, bootdev, installdev, kernel=None, initrd=None,
@@ -444,7 +455,7 @@ class Guest(object):
         # uuid
         oz.ozutil.lxml_subelement(domain, "uuid", str(self.uuid))
         # clock offset
-        oz.ozutil.lxml_subelement(domain, "clock", None, {'offset':self.clockoffset})
+        oz.ozutil.lxml_subelement(domain, "clock", None, {'offset': self.clockoffset})
         # vcpu
         oz.ozutil.lxml_subelement(domain, "vcpu", str(self.install_cpus))
         # features
@@ -456,7 +467,7 @@ class Guest(object):
         if self.tdl.arch in ["aarch64", "armv7l"] and self.libvirt_type == "kvm":
             # Possibly related to BZ 1171501 - need host passthrough for aarch64 and arm with kvm
             cpu = oz.ozutil.lxml_subelement(domain, "cpu", None, {'mode': 'custom', 'match': 'exact'})
-            model = oz.ozutil.lxml_subelement(cpu, "model", "host", {'fallback': 'allow'})
+            oz.ozutil.lxml_subelement(cpu, "model", "host", {'fallback': 'allow'})
         # os
         osNode = oz.ozutil.lxml_subelement(domain, "os")
         mods = None
@@ -464,7 +475,7 @@ class Guest(object):
             mods = {'arch': self.tdl.arch, 'machine': 'virt'}
         oz.ozutil.lxml_subelement(osNode, "type", "hvm", mods)
         if bootdev:
-            oz.ozutil.lxml_subelement(osNode, "boot", None, {'dev':bootdev})
+            oz.ozutil.lxml_subelement(osNode, "boot", None, {'dev': bootdev})
         if kernel:
             oz.ozutil.lxml_subelement(osNode, "kernel", kernel)
         if initrd:
@@ -484,24 +495,24 @@ class Guest(object):
         # devices
         devices = oz.ozutil.lxml_subelement(domain, "devices")
         # graphics
-        if not self.tdl.arch in ["aarch64", "armv7l"]:
-            # qemu for arm/aarch64 does not support a graphical console - amazingly
-            oz.ozutil.lxml_subelement(devices, "graphics", None, {'port':'-1', 'type':'vnc'})
+        if self.tdl.arch not in ["aarch64", "armv7l", "s390x"]:
+            # qemu for arm/aarch64/s390x does not support a graphical console - amazingly
+            oz.ozutil.lxml_subelement(devices, "graphics", None, {'port': '-1', 'type': 'vnc'})
         # network
-        interface = oz.ozutil.lxml_subelement(devices, "interface", None, {'type':'bridge'})
-        oz.ozutil.lxml_subelement(interface, "source", None, {'bridge':self.bridge_name})
-        oz.ozutil.lxml_subelement(interface, "mac", None, {'address':self.macaddr})
-        oz.ozutil.lxml_subelement(interface, "model", None, {'type':self.nicmodel})
+        interface = oz.ozutil.lxml_subelement(devices, "interface", None, {'type': 'bridge'})
+        oz.ozutil.lxml_subelement(interface, "source", None, {'bridge': self.bridge_name})
+        oz.ozutil.lxml_subelement(interface, "mac", None, {'address': self.macaddr})
+        oz.ozutil.lxml_subelement(interface, "model", None, {'type': self.nicmodel})
         # input
-        mousedict = {'bus':self.mousetype}
+        mousedict = {'bus': self.mousetype}
         if self.mousetype == "ps2":
             mousedict['type'] = 'mouse'
         elif self.mousetype == "usb":
             mousedict['type'] = 'tablet'
         oz.ozutil.lxml_subelement(devices, "input", None, mousedict)
         # serial console pseudo TTY
-        console = oz.ozutil.lxml_subelement(devices, "serial", None, {'type':'pty'})
-        oz.ozutil.lxml_subelement(console, "target", None, {'port':'0'})
+        console = oz.ozutil.lxml_subelement(devices, "serial", None, {'type': 'pty'})
+        oz.ozutil.lxml_subelement(console, "target", None, {'port': '0'})
         # serial
         self._generate_serial_xml(devices)
         # virtio
@@ -510,11 +521,15 @@ class Guest(object):
             self.has_consolelog = True
         else:
             self.has_consolelog = False
+        # virtio-rng
+        virtioRNG = oz.ozutil.lxml_subelement(devices, "rng", None, {'model': 'virtio'})
+        oz.ozutil.lxml_subelement(virtioRNG, "rate", None, {'bytes': '1024', 'period': '1000'})
+        oz.ozutil.lxml_subelement(virtioRNG, "backend", "/dev/random", {'model': 'random'})
         # boot disk
-        bootDisk = oz.ozutil.lxml_subelement(devices, "disk", None, {'device':'disk', 'type':'file'})
-        oz.ozutil.lxml_subelement(bootDisk, "target", None, {'dev':self.disk_dev, 'bus':self.disk_bus})
-        oz.ozutil.lxml_subelement(bootDisk, "source", None, {'file':self.diskimage})
-        oz.ozutil.lxml_subelement(bootDisk, "driver", None, {'name':'qemu', 'type':self.image_type})
+        bootDisk = oz.ozutil.lxml_subelement(devices, "disk", None, {'device': 'disk', 'type': 'file'})
+        oz.ozutil.lxml_subelement(bootDisk, "target", None, {'dev': self.disk_dev, 'bus': self.disk_bus})
+        oz.ozutil.lxml_subelement(bootDisk, "source", None, {'file': self.diskimage})
+        oz.ozutil.lxml_subelement(bootDisk, "driver", None, {'name': 'qemu', 'type': self.image_type})
         # install disk (if any)
         if not installdev:
             installdev_list = []
@@ -522,12 +537,12 @@ class Guest(object):
             installdev_list = [installdev]
         else:
             installdev_list = installdev
-        for installdev in installdev_list:
-            install = oz.ozutil.lxml_subelement(devices, "disk", None, {'type':'file', 'device':installdev.devicetype})
-            oz.ozutil.lxml_subelement(install, "source", None, {'file':installdev.path})
-            oz.ozutil.lxml_subelement(install, "target", None, {'dev':installdev.bus})
+        for idev in installdev_list:
+            install = oz.ozutil.lxml_subelement(devices, "disk", None, {'type': 'file', 'device': idev.devicetype})
+            oz.ozutil.lxml_subelement(install, "source", None, {'file': idev.path})
+            oz.ozutil.lxml_subelement(install, "target", None, {'dev': idev.bus})
 
-        xml = lxml.etree.tostring(domain, pretty_print=True)
+        xml = lxml.etree.tostring(domain, pretty_print=True, encoding="unicode")
         self.log.debug("Generated XML:\n%s", xml)
 
         return xml
@@ -562,7 +577,7 @@ class Guest(object):
         oz.ozutil.lxml_subelement(pool, "name", "oztempdir" + str(uuid.uuid4()))
         target = oz.ozutil.lxml_subelement(pool, "target")
         oz.ozutil.lxml_subelement(target, "path", directory)
-        pool_xml = lxml.etree.tostring(pool, pretty_print=True)
+        pool_xml = lxml.etree.tostring(pool, pretty_print=True, encoding="unicode")
 
         # create the volume XML
         vol = lxml.etree.Element("volume", type="file")
@@ -573,7 +588,7 @@ class Guest(object):
         if backing_filename:
             # Only qcow2 supports image creation using a backing file
             imgtype = "qcow2"
-        oz.ozutil.lxml_subelement(target, "format", None, {"type":imgtype})
+        oz.ozutil.lxml_subelement(target, "format", None, {"type": imgtype})
 
         # FIXME: this makes the permissions insecure, but is needed since
         # libvirt launches guests as qemu:qemu
@@ -597,10 +612,10 @@ class Guest(object):
             backing = oz.ozutil.lxml_subelement(vol, "backingStore")
             oz.ozutil.lxml_subelement(backing, "path", backing_filename)
             oz.ozutil.lxml_subelement(backing, "format", None,
-                                      {"type":backing_format})
+                                      {"type": backing_format})
 
-        oz.ozutil.lxml_subelement(vol, "capacity", str(capacity), {'unit':'G'})
-        vol_xml = lxml.etree.tostring(vol, pretty_print=True)
+        oz.ozutil.lxml_subelement(vol, "capacity", str(capacity), {'unit': 'G'})
+        vol_xml = lxml.etree.tostring(vol, pretty_print=True, encoding="unicode")
 
         # sigh.  Yes, this is racy; if a pool is defined during this loop, we
         # might miss it.  I'm not quite sure how to do it better, and in any
@@ -809,7 +824,7 @@ class Guest(object):
                     # is no guarantee that we will get the whole write in one go
                     data = self.sock.recv(65536)
                     if data:
-                        self.log.debug(data)
+                        self.log.debug(data.decode('utf-8'))
                 except socket.timeout:
                     # the socket times out after 1 second.  We can just fall
                     # through to the below code because it is a noop.
@@ -938,7 +953,7 @@ class Guest(object):
 
         info = oz.ozutil.http_get_header(url)
 
-        if 'HTTP-Code' not in info or info['HTTP-Code'] >= 400 or 'Content-Length' not in info or info['Content-Length'] < 0:
+        if 'HTTP-Code' not in info or int(info['HTTP-Code']) >= 400 or 'Content-Length' not in info or int(info['Content-Length']) < 0:
             raise oz.OzException.OzException("Could not reach %s to fetch boot media: %r" % (url, info))
 
         content_length = int(info['Content-Length'])
@@ -957,7 +972,7 @@ class Guest(object):
         # before fetching everything, make sure that we have enough
         # space on the filesystem to store the data we are about to download
         devdata = os.statvfs(outdir)
-        if (devdata.f_bsize*devdata.f_bavail) < content_length:
+        if (devdata.f_bsize * devdata.f_bavail) < content_length:
             raise oz.OzException.OzException("Not enough room on %s for install media" % (outdir))
 
         # at this point we know we are going to download something.  Make
@@ -987,7 +1002,7 @@ class Guest(object):
         domxml = libvirt_dom.XMLDesc(0)
         doc = lxml.etree.fromstring(domxml)
         graphics = doc.xpath("/domain/devices/graphics")
-        if len(graphics) == 0:
+        if not graphics:
             return "No graphics device found, screenshot skipped"
 
         oz.ozutil.mkdir_p(self.screenshot_dir)
@@ -1008,14 +1023,14 @@ class Guest(object):
             screenshot = os.path.realpath(os.path.join(self.screenshot_dir,
                                                        self.tdl.name + "-" + str(time.time()) + ext))
 
-            def sink(stream, buf, opaque):
+            def sink(stream, buf, opaque):  # pylint: disable=unused-argument
                 """
                 Function that is called back from the libvirt stream.
                 """
                 # opaque is the open file object
                 return oz.ozutil.write_bytes_to_fd(opaque, buf)
 
-            fd = os.open(screenshot, os.O_RDWR|os.O_CREAT)
+            fd = os.open(screenshot, os.O_RDWR | os.O_CREAT)
             try:
                 st.recvAll(sink, fd)
             finally:
@@ -1023,7 +1038,7 @@ class Guest(object):
 
             st.finish()
             text = "Check screenshot at %s for more detail" % (screenshot)
-        except:
+        except Exception:
             text = "Failed to take screenshot"
 
         return text
@@ -1059,7 +1074,7 @@ class Guest(object):
 
         self._generate_serial_xml(devices[0])
 
-        xml = lxml.etree.tostring(input_doc, pretty_print=True)
+        xml = lxml.etree.tostring(input_doc, pretty_print=True, encoding="unicode")
         self.log.debug("Generated XML:\n%s", xml)
         return xml
 
@@ -1089,7 +1104,7 @@ class Guest(object):
         else:
             raise oz.OzException.OzException("Found a disk with an unexpected number of driver sections")
 
-        xml = lxml.etree.tostring(input_doc, pretty_print=True)
+        xml = lxml.etree.tostring(input_doc, pretty_print=True, encoding="unicode")
         self.log.debug("Generated XML:\n%s", xml)
         return xml
 
@@ -1109,7 +1124,7 @@ class Guest(object):
             self.sock.connect(('127.0.0.1', self.listen_port))
 
             self.addr = None
-            self.data = ''
+            self.data = b''
 
             def _boot_cb(self):
                 '''
@@ -1118,7 +1133,7 @@ class Guest(object):
                 try:
                     # note that we have to build the data up here, since there
                     # is no guarantee that we will get the whole write in one go
-                    self.data += self.sock.recv(100)
+                    self.data += self.sock.recv(8192)
                 except socket.timeout:
                     # the socket times out after 1 second.  We can just fall
                     # through to the below code because it is a noop.
@@ -1129,22 +1144,22 @@ class Guest(object):
                 # followed by a !<ip>,<uuid>!
                 # Exclude ! from the wildcard to avoid errors when receiving two
                 # announce messages in the same string
-                match = re.search("!([^!]*?,[^!]*?)!$", self.data)
+                match = re.search(b"!([^!]*?,[^!]*?)!$", self.data)
                 if match is not None:
                     if len(match.groups()) != 1:
                         raise oz.OzException.OzException("Guest checked in with no data")
-                    split = match.group(1).split(',')
+                    split = match.group(1).split(b',')
                     if len(split) != 2:
                         raise oz.OzException.OzException("Guest checked in with bogus data")
                     self.addr = split[0]
                     uuidstr = split[1]
                     try:
                         # use socket.inet_aton() to validate the IP address
-                        socket.inet_aton(self.addr)
+                        socket.inet_aton(self.addr.decode('utf-8'))
                     except socket.error:
                         raise oz.OzException.OzException("Guest checked in with invalid IP address")
 
-                    if uuidstr != str(self.uuid):
+                    if uuidstr.decode('utf-8') != str(self.uuid):
                         raise oz.OzException.OzException("Guest checked in with unknown UUID")
                     return True
 
@@ -1163,6 +1178,7 @@ class Guest(object):
         if self.addr is None:
             raise oz.OzException.OzException("Timed out waiting for guest to boot")
 
+        self.addr = self.addr.decode('utf-8')
         self.log.debug("IP address of guest is %s", self.addr)
 
         return self.addr
@@ -1184,11 +1200,11 @@ class Guest(object):
             if line == "":
                 continue
             package = oz.ozutil.lxml_subelement(packages, "package", None,
-                                                {'name':line})
+                                                {'name': line})
             if extra is not None:
                 oz.ozutil.lxml_subelement(package, "extra", extra[index])
 
-        return lxml.etree.tostring(icicle, pretty_print=True)
+        return lxml.etree.tostring(icicle, pretty_print=True, encoding="unicode")
 
     def _check_url(self, iso=True, url=True):
         """
@@ -1242,7 +1258,7 @@ class Guest(object):
         # when we get here, either both the private and public key exist, or
         # neither exist.  If they don't exist, generate them
         if not os.access(privname, os.F_OK) and not os.access(pubname, os.F_OK):
-            def _null_callback(p, n, out):
+            def _null_callback(p, n, out):  # pylint: disable=unused-argument
                 """
                 Method to silence the default M2Crypto.RSA.gen_key output.
                 """
@@ -1261,19 +1277,21 @@ class Guest(object):
             # we can just use them as-is.  We then have to base64 encode the
             # result, add a little header information, and then we have a
             # full public key.
-            pubkey = '\x00\x00\x00\x07' + 'ssh-rsa' + key.e + key.n
+            pubkey = b'\x00\x00\x00\x07' + b'ssh-rsa' + key.e + key.n
 
             username = os.getlogin()
             hostname = os.uname()[1]
-            keystring = 'ssh-rsa %s %s@%s\n' % (base64.b64encode(pubkey),
+            keystring = 'ssh-rsa %s %s@%s\n' % (base64.b64encode(pubkey).decode('utf-8'),
                                                 username, hostname)
 
+            oz.ozutil.mkdir_p(os.path.dirname(privname))
             key.save_key(privname, cipher=None)
             os.chmod(privname, 0o600)
             with open(pubname, 'w') as f:
                 f.write(keystring)
             os.chmod(pubname, 0o644)
 
+
 class CDGuest(Guest):
     """
     Class for guest installation via ISO.
@@ -1344,7 +1362,7 @@ class CDGuest(Guest):
             self.log.debug("Checking if there is enough space on the filesystem")
             isostat = gfs.statvfs("/")
             outputstat = os.statvfs(self.iso_contents)
-            if (outputstat.f_bsize*outputstat.f_bavail) < (isostat['blocks']*isostat['bsize']):
+            if (outputstat.f_bsize * outputstat.f_bavail) < (isostat['blocks'] * isostat['bsize']):
                 raise oz.OzException.OzException("Not enough room on %s to extract install media" % (self.iso_contents))
 
             self.log.debug("Extracting ISO contents")
@@ -1407,9 +1425,12 @@ class CDGuest(Guest):
         Method to extract the primary volume descriptor from a CD.
         """
         # check out the primary volume descriptor to make sure it is sane
-        cdfd.seek(16*2048)
-        fmt = "=B5sBB32s32sQLL32sHHHH"
-        (desc_type, identifier, version, unused1, system_identifier, volume_identifier, unused2, space_size_le, space_size_be, unused3, set_size_le, set_size_be, seqnum_le, seqnum_be) = struct.unpack(fmt, cdfd.read(struct.calcsize(fmt)))
+        cdfd.seek(16 * 2048)
+        fmt = b"=B5sBB32s32sQLL32sHHHH"
+        (desc_type, identifier, version, unused1, system_identifier,
+         volume_identifier, unused2, space_size_le, space_size_be_unused,
+         unused3, set_size_le, set_size_be, seqnum_le,
+         seqnum_be) = struct.unpack(fmt, cdfd.read(struct.calcsize(fmt)))
 
         if desc_type != 0x1:
             raise oz.OzException.OzException("Invalid primary volume descriptor")
@@ -1434,105 +1455,104 @@ class CDGuest(Guest):
         if outfile is None:
             raise oz.OzException.OzException("output file is None")
 
-        cdfd = open(cdfile, "r")
+        with open(cdfile, 'rb') as cdfd:
+            self._get_primary_volume_descriptor(cdfd)
 
-        self._get_primary_volume_descriptor(cdfd)
+            # the 17th sector contains the boot specification and the offset of the
+            # boot sector
+            cdfd.seek(17 * 2048)
 
-        # the 17th sector contains the boot specification and the offset of the
-        # boot sector
-        cdfd.seek(17*2048)
+            # NOTE: With "native" alignment (the default for struct), there is
+            # some padding that happens that causes the unpacking to fail.
+            # Instead we force "standard" alignment, which has no padding
+            fmt = "=B5sB23s41sI"
+            (boot, isoIdent, version, toritoSpec, unused, bootP) = struct.unpack(fmt,
+                                                                                 cdfd.read(struct.calcsize(fmt)))
+            if boot != 0x0:
+                raise oz.OzException.OzException("invalid CD boot sector")
+            if isoIdent != "CD001":
+                raise oz.OzException.OzException("invalid CD isoIdentification")
+            if version != 0x1:
+                raise oz.OzException.OzException("invalid CD version")
+            if toritoSpec != "EL TORITO SPECIFICATION":
+                raise oz.OzException.OzException("invalid CD torito specification")
 
-        # NOTE: With "native" alignment (the default for struct), there is
-        # some padding that happens that causes the unpacking to fail.
-        # Instead we force "standard" alignment, which has no padding
-        fmt = "=B5sB23s41sI"
-        (boot, isoIdent, version, toritoSpec, unused, bootP) = struct.unpack(fmt,
-                                                                             cdfd.read(struct.calcsize(fmt)))
-        if boot != 0x0:
-            raise oz.OzException.OzException("invalid CD boot sector")
-        if isoIdent != "CD001":
-            raise oz.OzException.OzException("invalid CD isoIdentification")
-        if version != 0x1:
-            raise oz.OzException.OzException("invalid CD version")
-        if toritoSpec != "EL TORITO SPECIFICATION":
-            raise oz.OzException.OzException("invalid CD torito specification")
+            # OK, this looks like a bootable CD.  Seek to the boot sector, and
+            # look for the header, 0x55, and 0xaa in the first 32 bytes
+            cdfd.seek(bootP * 2048)
+            fmt = "=BBH24sHBB"
+            bootdata = cdfd.read(struct.calcsize(fmt))
+            (header, platform, unused, manu_unused, unused2, five, aa) = struct.unpack(fmt,
+                                                                                       bootdata)
+            if header != 0x1:
+                raise oz.OzException.OzException("invalid CD boot sector header")
+            if platform != 0x0 and platform != 0x1 and platform != 0x2:
+                raise oz.OzException.OzException("invalid CD boot sector platform")
+            if unused != 0x0:
+                raise oz.OzException.OzException("invalid CD unused boot sector field")
+            if five != 0x55 or aa != 0xaa:
+                raise oz.OzException.OzException("invalid CD boot sector footer")
 
-        # OK, this looks like a bootable CD.  Seek to the boot sector, and
-        # look for the header, 0x55, and 0xaa in the first 32 bytes
-        cdfd.seek(bootP*2048)
-        fmt = "=BBH24sHBB"
-        bootdata = cdfd.read(struct.calcsize(fmt))
-        (header, platform, unused, manu, unused2, five, aa) = struct.unpack(fmt,
-                                                                            bootdata)
-        if header != 0x1:
-            raise oz.OzException.OzException("invalid CD boot sector header")
-        if platform != 0x0 and platform != 0x1 and platform != 0x2:
-            raise oz.OzException.OzException("invalid CD boot sector platform")
-        if unused != 0x0:
-            raise oz.OzException.OzException("invalid CD unused boot sector field")
-        if five != 0x55 or aa != 0xaa:
-            raise oz.OzException.OzException("invalid CD boot sector footer")
+            def _checksum(data):
+                """
+                Method to compute the checksum on the ISO.  Note that this is *not*
+                a 1's complement checksum; when an addition overflows, the carry
+                bit is discarded, not added to the end.
+                """
+                s = 0
+                for i in range(0, len(data), 2):
+                    w = ord(data[i]) + (ord(data[i + 1]) << 8)
+                    s = (s + w) & 0xffff
+                return s
 
-        def _checksum(data):
-            """
-            Method to compute the checksum on the ISO.  Note that this is *not*
-            a 1's complement checksum; when an addition overflows, the carry
-            bit is discarded, not added to the end.
-            """
-            s = 0
-            for i in range(0, len(data), 2):
-                w = ord(data[i]) + (ord(data[i+1]) << 8)
-                s = (s + w) & 0xffff
-            return s
+            csum = _checksum(bootdata)
+            if csum != 0:
+                raise oz.OzException.OzException("invalid CD checksum: expected 0, saw %d" % (csum))
 
-        csum = _checksum(bootdata)
-        if csum != 0:
-            raise oz.OzException.OzException("invalid CD checksum: expected 0, saw %d" % (csum))
+            # OK, everything so far has checked out.  Read the default/initial
+            # boot entry
+            cdfd.seek(bootP * 2048 + 32)
+            fmt = "=BBHBBHIB"
+            (boot, media, loadsegment_unused, systemtype_unused, unused, scount,
+             imgstart, unused2) = struct.unpack(fmt, cdfd.read(struct.calcsize(fmt)))
 
-        # OK, everything so far has checked out.  Read the default/initial
-        # boot entry
-        cdfd.seek(bootP*2048+32)
-        fmt = "=BBHBBHIB"
-        (boot, media, loadsegment, systemtype, unused, scount, imgstart, unused2) = struct.unpack(fmt, cdfd.read(struct.calcsize(fmt)))
+            if boot != 0x88:
+                raise oz.OzException.OzException("invalid CD initial boot indicator")
+            if unused != 0x0 or unused2 != 0x0:
+                raise oz.OzException.OzException("invalid CD initial boot unused field")
 
-        if boot != 0x88:
-            raise oz.OzException.OzException("invalid CD initial boot indicator")
-        if unused != 0x0 or unused2 != 0x0:
-            raise oz.OzException.OzException("invalid CD initial boot unused field")
+            if media == 0 or media == 4:
+                count = scount
+            elif media == 1:
+                # 1.2MB floppy in sectors
+                count = 1200 * 1024 / 512
+            elif media == 2:
+                # 1.44MB floppy in sectors
+                count = 1440 * 1024 / 512
+            elif media == 3:
+                # 2.88MB floppy in sectors
+                count = 2880 * 1024 / 512
+            else:
+                raise oz.OzException.OzException("invalid CD media type")
 
-        if media == 0 or media == 4:
-            count = scount
-        elif media == 1:
-            # 1.2MB floppy in sectors
-            count = 1200*1024/512
-        elif media == 2:
-            # 1.44MB floppy in sectors
-            count = 1440*1024/512
-        elif media == 3:
-            # 2.88MB floppy in sectors
-            count = 2880*1024/512
-        else:
-            raise oz.OzException.OzException("invalid CD media type")
+            # finally, seek to "imgstart", and read "count" sectors, which
+            # contains the boot image
+            cdfd.seek(imgstart * 2048)
 
-        # finally, seek to "imgstart", and read "count" sectors, which
-        # contains the boot image
-        cdfd.seek(imgstart*2048)
-
-        # The eltorito specification section 2.5 says:
-        #
-        # Sector Count. This is the number of virtual/emulated sectors the
-        # system will store at Load Segment during the initial boot
-        # procedure.
-        #
-        # and then Section 1.5 says:
-        #
-        # Virtual Disk - A series of sectors on the CD which INT 13 presents
-        # to the system as a drive with 200 byte virtual sectors. There
-        # are 4 virtual sectors found in each sector on a CD.
-        #
-        # (note that the bytes above are in hex).  So we read count*512
-        eltoritodata = cdfd.read(count*512)
-        cdfd.close()
+            # The eltorito specification section 2.5 says:
+            #
+            # Sector Count. This is the number of virtual/emulated sectors the
+            # system will store at Load Segment during the initial boot
+            # procedure.
+            #
+            # and then Section 1.5 says:
+            #
+            # Virtual Disk - A series of sectors on the CD which INT 13 presents
+            # to the system as a drive with 200 byte virtual sectors. There
+            # are 4 virtual sectors found in each sector on a CD.
+            #
+            # (note that the bytes above are in hex).  So we read count*512
+            eltoritodata = cdfd.read(count * 512)
 
         with open(outfile, "w") as f:
             f.write(eltoritodata)
@@ -1625,7 +1645,7 @@ class CDGuest(Guest):
             elif parsedurl.scheme == "ftp":
                 if isoextra.element_type == "file":
                     fd = os.open(targetabspath,
-                                 os.O_CREAT|os.O_TRUNC|os.O_WRONLY)
+                                 os.O_CREAT | os.O_TRUNC | os.O_WRONLY)
                     try:
                         oz.ozutil.http_download_file(isoextra.source, fd, True,
                                                      self.log)
@@ -1636,13 +1656,14 @@ class CDGuest(Guest):
                                                      parsedurl.username,
                                                      parsedurl.password,
                                                      parsedurl.path,
-                                                     targetabspath)
+                                                     targetabspath,
+                                                     parsedurl.port)
             elif parsedurl.scheme == "http":
                 if isoextra.element_type == "directory":
                     raise oz.OzException.OzException("ISO extra directories cannot be fetched over HTTP")
                 else:
                     fd = os.open(targetabspath,
-                                 os.O_CREAT|os.O_TRUNC|os.O_WRONLY)
+                                 os.O_CREAT | os.O_TRUNC | os.O_WRONLY)
                     try:
                         oz.ozutil.http_download_file(isoextra.source, fd, True,
                                                      self.log)
@@ -1750,6 +1771,7 @@ class CDGuest(Guest):
             except:
                 pass
 
+
 class FDGuest(Guest):
     """
     Class for guest installation via floppy disk.
@@ -1830,5 +1852,5 @@ class FDGuest(Guest):
         if not self.cache_original_media:
             try:
                 os.unlink(self.orig_floppy)
-            except:
+            except Exception:
                 pass
