@@ -1,4 +1,4 @@
-# Copyright (C) 2013-2016  Chris Lalancette <clalancette@gmail.com>
+# Copyright (C) 2013-2018  Chris Lalancette <clalancette@gmail.com>
 
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -18,9 +18,9 @@
 Mageia installation
 """
 
-import shutil
 import os
 import re
+import shutil
 try:
     import urllib.parse as urlparse
 except ImportError:
@@ -28,8 +28,54 @@ except ImportError:
 
 import oz.GuestFSManager
 import oz.Linux
-import oz.ozutil
 import oz.OzException
+import oz.ozutil
+
+
+class MageiaConfiguration(object):
+    """
+    Configuration class for Mageia installation.
+    """
+    def __init__(self, isolinux_style, default_netdev, default_diskbus):
+        self._isolinux_style = isolinux_style
+        self._default_netdev = default_netdev
+        self._default_diskbus = default_diskbus
+
+    @property
+    def isolinux_style(self):
+        """
+        Property method for the 'old' or 'new' isolinux style.
+        """
+        return self._isolinux_style
+
+    @property
+    def default_netdev(self):
+        """
+        Property method for the default netdev for this version of Mageia.
+        """
+        return self._default_netdev
+
+    @property
+    def default_diskbus(self):
+        """
+        Property method for the default diskbus for this version of Mageia.
+        """
+        return self._default_diskbus
+
+
+version_to_config = {
+    '5': MageiaConfiguration(isolinux_style="new", default_netdev='virtio',
+                             default_diskbus='virtio'),
+    '4.1': MageiaConfiguration(isolinux_style="new", default_netdev='virtio',
+                               default_diskbus='virtio'),
+    '4': MageiaConfiguration(isolinux_style="new", default_netdev='virtio',
+                             default_diskbus='virtio'),
+    '3': MageiaConfiguration(isolinux_style="old", default_netdev='virtio',
+                             default_diskbus='virtio'),
+    '2': MageiaConfiguration(isolinux_style="old", default_netdev='virtio',
+                             default_diskbus='virtio'),
+}
+
 
 class MageiaGuest(oz.Linux.LinuxCDGuest):
     """
@@ -37,6 +83,11 @@ class MageiaGuest(oz.Linux.LinuxCDGuest):
     """
     def __init__(self, tdl, config, auto, output_disk, netdev, diskbus,
                  macaddress):
+        self.config = version_to_config[tdl.update]
+        if netdev is None:
+            netdev = self.config.default_netdev
+        if diskbus is None:
+            diskbus = self.config.default_diskbus
         oz.Linux.LinuxCDGuest.__init__(self, tdl, config, auto, output_disk,
                                        netdev, diskbus, True, True,
                                        macaddress)
@@ -63,8 +114,7 @@ class MageiaGuest(oz.Linux.LinuxCDGuest):
                 """
                 if re.search("'password' =>", line):
                     return "			'password' => '" + self.rootpw + "',\n"
-                else:
-                    return line
+                return line
 
             oz.ozutil.copy_modify_file(self.auto, outname, _cfg_sub)
         else:
@@ -77,30 +127,46 @@ class MageiaGuest(oz.Linux.LinuxCDGuest):
                                            "::AUTO_INST.CFG"])
 
         self.log.debug("Modifying isolinux.cfg")
-        if self.tdl.update == "2":
-            '''
-            Mageia 2 dual   - isolinux/32.cfg
-                              isolinux/64.cfg
-                              isolinux/alt0/32/vmlinuz
-                              isolinux/alt0/32/all.rdz
-                              isolinux/alt0/64/vmlinuz
-                              isolinux/alt0/64/all.rdz
-            Mageia 2 x86_64 - x86_64/isolinux/isolinux.cfg
-                              x86_64/isolinux/alt0/vmlinuz
-                              x86_64/isolinux/alt0/all.rdz
-            Mageia 2 i586   - i586/isolinux/isolinux.cfg
-                              i586/isolinux/vmlinuz
-                              i586/isolinux/all.rdz
-            '''
+        if self.config.isolinux_style == "old":
+            # Mageia 2 dual   - isolinux/32.cfg
+            #                   isolinux/64.cfg
+            #                   isolinux/alt0/32/vmlinuz
+            #                   isolinux/alt0/32/all.rdz
+            #                   isolinux/alt0/64/vmlinuz
+            #                   isolinux/alt0/64/all.rdz
+            # Mageia 2 x86_64 - x86_64/isolinux/isolinux.cfg
+            #                   x86_64/isolinux/alt0/vmlinuz
+            #                   x86_64/isolinux/alt0/all.rdz
+            # Mageia 2 i586   - i586/isolinux/isolinux.cfg
+            #                   i586/isolinux/vmlinuz
+            #                   i586/isolinux/all.rdz
+            # Mageia 3 dual   - syslinux/32.cfg
+            #                   syslinux/64.cfg
+            #                   syslinux/alt0/32/vmlinuz
+            #                   syslinux/alt0/32/all.rdz
+            #                   syslinux/alt0/64/vmlinuz
+            #                   syslinux/alt0/64/all.rdz
+            # Mageia 3 x86_64 - x86_64/isolinux/isolinux.cfg
+            #                   x86_64/isolinux/alt0/vmlinuz
+            #                   x86_64/isolinux/alt0/all.rdz
+            # Mageia 3 i586   - i586/isolinux/isolinux.cfg
+            #                   i586/isolinux/alt0/vmlinuz
+            #                   i586/isolinux/alt0/all.rdz
+            isolinuxstr = None
             if os.path.exists(os.path.join(self.iso_contents, 'isolinux')):
+                isolinuxstr = "isolinux"
+            elif os.path.exists(os.path.join(self.iso_contents, 'syslinux')):
+                isolinuxstr = "syslinux"
+
+            if isolinuxstr is not None:
                 if self.tdl.arch == "i386":
                     mageia_arch = "32"
                 else:
                     mageia_arch = "64"
 
                 # This looks like a dual CD, so let's set things up that way.
-                isolinuxcfg = os.path.join(self.iso_contents, 'isolinux', mageia_arch + ".cfg")
-                self.isolinuxbin = os.path.join('isolinux', mageia_arch + ".bin")
+                isolinuxcfg = os.path.join(self.iso_contents, isolinuxstr, mageia_arch + ".cfg")
+                self.isolinuxbin = os.path.join(isolinuxstr, mageia_arch + ".bin")
                 kernel = "alt0/" + mageia_arch + "/vmlinuz"
                 initrd = "alt0/" + mageia_arch + "/all.rdz"
             else:
@@ -113,78 +179,44 @@ class MageiaGuest(oz.Linux.LinuxCDGuest):
                 kernel = "alt0/vmlinuz"
                 initrd = "alt0/all.rdz"
             flags = "ramdisk_size=128000 root=/dev/ram3 acpi=ht vga=788 automatic=method:cdrom"
-        elif self.tdl.update == "3":
-            '''
-            Mageia 3 dual   - syslinux/32.cfg
-                              syslinux/64.cfg
-                              syslinux/alt0/32/vmlinuz
-                              syslinux/alt0/32/all.rdz
-                              syslinux/alt0/64/vmlinuz
-                              syslinux/alt0/64/all.rdz
-            Mageia 3 x86_64 - x86_64/isolinux/isolinux.cfg
-                              x86_64/isolinux/alt0/vmlinuz
-                              x86_64/isolinux/alt0/all.rdz
-            Mageia 3 i586   - i586/isolinux/isolinux.cfg
-                              i586/isolinux/alt0/vmlinuz
-                              i586/isolinux/alt0/all.rdz
-            '''
-            if os.path.exists(os.path.join(self.iso_contents, 'syslinux')):
-                if self.tdl.arch == "i386":
-                    mageia_arch = "32"
-                else:
-                    mageia_arch = "64"
-                isolinuxcfg = os.path.join(self.iso_contents, 'syslinux', mageia_arch + ".cfg")
-                self.isolinuxbin = os.path.join('syslinux', mageia_arch + ".bin")
-                kernel = "alt0/" + mageia_arch + "/vmlinuz"
-                initrd = "alt0/" + mageia_arch + "/all.rdz"
-            else:
-                mageia_arch = self.tdl.arch
-                if self.tdl.arch == "i386":
-                    mageia_arch = "i586"
-                isolinuxcfg = os.path.join(self.iso_contents, mageia_arch, 'isolinux', 'isolinux.cfg')
-                self.isolinuxbin = os.path.join(mageia_arch, 'isolinux', 'isolinux.bin')
-                kernel = "alt0/vmlinuz"
-                initrd = "alt0/all.rdz"
-            flags = "ramdisk_size=128000 root=/dev/ram3 acpi=ht vga=788 automatic=method:cdrom"
-        elif self.tdl.update in ["4", "4.1", "5"]:
-            '''
-            Mageia 4 dual     - isolinux/i586.cfg
-                                isolinux/x86_64.cfg
-                                isolinux/i586/vmlinuz
-                                isolinux/i586/all.rdz
-                                isolinux/x86_64/vmlinuz
-                                isolinux/x86_64/all.rdz
-            Mageia 4 x86_64   - isolinux/isolinux.cfg
-                                isolinux/x86_64/vmlinuz
-                                isolinux/x86_64/all.rdz
-            Mageia 4 i586     - isolinux/isolinux.cfg
-                                isolinux/i586/vmlinuz
-                                isolinuz/i586/all.rdz
-            Mageia 4.1 dual   - isolinux/i586.cfg
-                                isolinux/x86_64.cfg
-                                isolinux/i586/vmlinuz
-                                isolinux/i586/all.rdz
-                                isolinux/x86_64/vmlinuz
-                                isolinux/x86_64/all.rdz
-            Mageia 4.1 x86_64 - isolinux/isolinux.cfg
-                                isolinux/x86_64/vmlinuz
-                                isolinux/x86_64/all.rdz
-            Mageia 4.1 i586 -   isolinux/isolinux.cfg
-                                isolinux/i586/vmlinuz
-                                isolinux/i586/all.rdz
-            Mageia 5 dual     - isolinux/i586.cfg
-                                isolinux/x86_64.cfg
-                                isolinux/i586/vmlinuz
-                                isolinux/i586/all.rdz
-                                isolinux/x86_64/vmlinuz
-                                isolinux/x86_64/all.rdz
-            Mageia 5 x86_64   - isolinux/isolinux.cfg
-                                isolinux/x86_64/vmlinuz
-                                isolinux/x86_64/all.rdz
-            Mageia 5 i586 -     isolinux/isolinux.cfg
-                                isolinux/i586/vmlinuz
-                                isolinux/i586/all.rdz
-            '''
+        else:
+            # Mageia 4 dual     - isolinux/i586.cfg
+            #                     isolinux/x86_64.cfg
+            #                     isolinux/i586/vmlinuz
+            #                     isolinux/i586/all.rdz
+            #                     isolinux/x86_64/vmlinuz
+            #                     isolinux/x86_64/all.rdz
+            # Mageia 4 x86_64   - isolinux/isolinux.cfg
+            #                     isolinux/x86_64/vmlinuz
+            #                     isolinux/x86_64/all.rdz
+            # Mageia 4 i586     - isolinux/isolinux.cfg
+            #                     isolinux/i586/vmlinuz
+            #                     isolinuz/i586/all.rdz
+            # Mageia 4.1 dual   - isolinux/i586.cfg
+            #                     isolinux/x86_64.cfg
+            #                     isolinux/i586/vmlinuz
+            #                     isolinux/i586/all.rdz
+            #                     isolinux/x86_64/vmlinuz
+            #                     isolinux/x86_64/all.rdz
+            # Mageia 4.1 x86_64 - isolinux/isolinux.cfg
+            #                     isolinux/x86_64/vmlinuz
+            #                     isolinux/x86_64/all.rdz
+            # Mageia 4.1 i586 -   isolinux/isolinux.cfg
+            #                     isolinux/i586/vmlinuz
+            #                     isolinux/i586/all.rdz
+            # Mageia 5 dual     - isolinux/i586.cfg
+            #                     isolinux/x86_64.cfg
+            #                     isolinux/i586/vmlinuz
+            #                     isolinux/i586/all.rdz
+            #                     isolinux/x86_64/vmlinuz
+            #                     isolinux/x86_64/all.rdz
+            # Mageia 5 x86_64   - isolinux/isolinux.cfg
+            #                     isolinux/x86_64/vmlinuz
+            #                     isolinux/x86_64/all.rdz
+            # Mageia 5 i586 -     isolinux/isolinux.cfg
+            #                     isolinux/i586/vmlinuz
+            #                     isolinux/i586/all.rdz
+
             # Starting with Mageia 4, things are a lot more regular.  The
             # directory always starts with isolinux.  If it is a dual ISO, then
             # there is an i586.cfg and x86_64.cfg describing how to boot each
@@ -247,7 +279,7 @@ label customiso
             if re.match('# chkconfig:', line):
                 try:
                     startlevel = line.split(':')[1].split()[1]
-                except:
+                except Exception:
                     pass
                 break
 
@@ -495,17 +527,17 @@ echo -n "!$ADDR,%s!" > /dev/ttyS1
         XML.
         """
         self.log.debug("Generating ICICLE")
-        stdout, stderr, retcode = self.guest_execute_command(guestaddr,
-                                                             'rpm -qa',
-                                                             timeout=30)
+        stdout, stderr_unused, retcode_unused = self.guest_execute_command(guestaddr,
+                                                                           'rpm -qa',
+                                                                           timeout=30)
 
         package_split = stdout.split("\n")
 
         extrasplit = None
         if self.tdl.icicle_extra_cmd:
-            extrastdout, stderr, retcode = self.guest_execute_command(guestaddr,
-                                                                      self.tdl.icicle_extra_cmd,
-                                                                      timeout=30)
+            extrastdout, stderr_unused, retcode_unused = self.guest_execute_command(guestaddr,
+                                                                                    self.tdl.icicle_extra_cmd,
+                                                                                    timeout=30)
             extrasplit = extrastdout.split("\n")
 
             if len(package_split) != len(extrasplit):
@@ -534,21 +566,19 @@ echo -n "!$ADDR,%s!" > /dev/ttyS1
         return self._do_install(timeout, force, 0, None, None, None,
                                 [fddev])
 
+
 def get_class(tdl, config, auto, output_disk=None, netdev=None, diskbus=None,
               macaddress=None):
     """
     Factory method for Mageia installs.
     """
-    if tdl.update in ["2", "3", "4", "4.1", "5"]:
-        if netdev is None:
-            netdev = 'virtio'
-        if diskbus is None:
-            diskbus = 'virtio'
+    if tdl.update in version_to_config.keys():
         return MageiaGuest(tdl, config, auto, output_disk, netdev, diskbus,
                            macaddress)
 
+
 def get_supported_string():
     """
     Return supported versions as a string.
     """
-    return "Mageia: 2, 3, 4, 4.1, 5"
+    return "Mageia: " + ", ".join(sorted(version_to_config.keys()))
