@@ -1,5 +1,5 @@
 # Copyright (C) 2010,2011  Chris Lalancette <clalance@redhat.com>
-# Copyright (C) 2012-2017  Chris Lalancette <clalancette@gmail.com>
+# Copyright (C) 2012-2018  Chris Lalancette <clalancette@gmail.com>
 
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -19,15 +19,111 @@
 OpenSUSE installation
 """
 
+import os
 import re
 import shutil
-import os
+
 import lxml.etree
 
 import oz.GuestFSManager
 import oz.Linux
-import oz.ozutil
 import oz.OzException
+import oz.ozutil
+
+
+class OpenSUSEConfiguration(object):
+    """
+    Configuration class for OpenSUSE.
+    """
+    def __init__(self, reboots, use_floppy_autoyast, extended_zypper_list,
+                 default_netdev, default_diskbus):
+        self._reboots = reboots
+        self._use_floppy_autoyast = use_floppy_autoyast
+        self._extended_zypper_list = extended_zypper_list
+        self._default_netdev = default_netdev
+        self._default_diskbus = default_diskbus
+
+    @property
+    def reboots(self):
+        """
+        Property method for the number of reboots for installation of this
+        version of OpenSUSE.
+        """
+        return self._reboots
+
+    @property
+    def use_floppy_autoyast(self):
+        """
+        Property method to determine whether the autoyast should go on a
+        floppy or on the ISO.
+        """
+        return self._use_floppy_autoyast
+
+    @property
+    def extended_zypper_list(self):
+        """
+        Property method for where the URI is stored in the output of
+        'zypper list' in this version of OpenSUSE.
+        """
+        return self._extended_zypper_list
+
+    @property
+    def default_netdev(self):
+        """
+        Property method for the default netdev for this version of OpenSUSE.
+        """
+        return self._default_netdev
+
+    @property
+    def default_diskbus(self):
+        """
+        Property method for the default diskbus for this version of OpenSUSE.
+        """
+        return self._default_diskbus
+
+
+version_to_config = {
+    "42.2": OpenSUSEConfiguration(reboots=1, use_floppy_autoyast=False,
+                                  extended_zypper_list=True, default_netdev='virtio',
+                                  default_diskbus='virtio'),
+    "42.1": OpenSUSEConfiguration(reboots=1, use_floppy_autoyast=False,
+                                  extended_zypper_list=True, default_netdev='virtio',
+                                  default_diskbus='virtio'),
+    "13.2": OpenSUSEConfiguration(reboots=1, use_floppy_autoyast=True,
+                                  extended_zypper_list=False, default_netdev='virtio',
+                                  default_diskbus='virtio'),
+    "13.1": OpenSUSEConfiguration(reboots=1, use_floppy_autoyast=False,
+                                  extended_zypper_list=False, default_netdev='virtio',
+                                  default_diskbus='virtio'),
+    "12.3": OpenSUSEConfiguration(reboots=1, use_floppy_autoyast=False,
+                                  extended_zypper_list=False, default_netdev='virtio',
+                                  default_diskbus='virtio'),
+    "12.2": OpenSUSEConfiguration(reboots=1, use_floppy_autoyast=False,
+                                  extended_zypper_list=False, default_netdev='virtio',
+                                  default_diskbus='virtio'),
+    "12.1": OpenSUSEConfiguration(reboots=1, use_floppy_autoyast=False,
+                                  extended_zypper_list=False, default_netdev='virtio',
+                                  default_diskbus='virtio'),
+    "11.4": OpenSUSEConfiguration(reboots=1, use_floppy_autoyast=False,
+                                  extended_zypper_list=False, default_netdev='virtio',
+                                  default_diskbus='virtio'),
+    "11.3": OpenSUSEConfiguration(reboots=1, use_floppy_autoyast=False,
+                                  extended_zypper_list=False, default_netdev='virtio',
+                                  default_diskbus='virtio'),
+    "11.2": OpenSUSEConfiguration(reboots=1, use_floppy_autoyast=False,
+                                  extended_zypper_list=False, default_netdev='virtio',
+                                  default_diskbus='virtio'),
+    "11.1": OpenSUSEConfiguration(reboots=1, use_floppy_autoyast=False,
+                                  extended_zypper_list=False, default_netdev='virtio',
+                                  default_diskbus='virtio'),
+    "11.0": OpenSUSEConfiguration(reboots=1, use_floppy_autoyast=False,
+                                  extended_zypper_list=False, default_netdev='virtio',
+                                  default_diskbus='virtio'),
+    "10.3": OpenSUSEConfiguration(reboots=0, use_floppy_autoyast=False,
+                                  extended_zypper_list=False, default_netdev=None,
+                                  default_diskbus=None),
+}
+
 
 class OpenSUSEGuest(oz.Linux.LinuxCDGuest):
     """
@@ -35,16 +131,17 @@ class OpenSUSEGuest(oz.Linux.LinuxCDGuest):
     """
     def __init__(self, tdl, config, auto, output_disk, nicmodel, diskbus,
                  macaddress):
+        self.config = version_to_config[tdl.update]
+        if nicmodel is None:
+            nicmodel = self.config.default_netdev
+        if diskbus is None:
+            diskbus = self.config.default_diskbus
         oz.Linux.LinuxCDGuest.__init__(self, tdl, config, auto, output_disk,
                                        nicmodel, diskbus, True, False,
                                        macaddress)
 
         self.crond_was_active = False
         self.sshd_was_active = False
-        self.reboots = 1
-        if self.tdl.update in ["10.3"]:
-            # for 10.3 we don't have a 2-stage install process so don't reboot
-            self.reboots = 0
 
     def _modify_iso(self):
         """
@@ -58,18 +155,17 @@ class OpenSUSEGuest(oz.Linux.LinuxCDGuest):
             doc = lxml.etree.parse(self.auto)
 
             pw = doc.xpath('/suse:profile/suse:users/suse:user/suse:user_password',
-                           namespaces={'suse':'http://www.suse.com/1.0/yast2ns'})
+                           namespaces={'suse': 'http://www.suse.com/1.0/yast2ns'})
             if len(pw) != 1:
                 raise oz.OzException.OzException("Invalid SUSE autoyast file; expected single user_password, saw %d" % (len(pw)))
             pw[0].text = self.rootpw
 
-            f = open(outname, 'w')
-            f.write(lxml.etree.tostring(doc, pretty_print=True))
-            f.close()
+            with open(outname, 'w') as f:
+                f.write(lxml.etree.tostring(doc, pretty_print=True, encoding="unicode"))
         else:
             shutil.copy(self.auto, outname)
 
-        if self.tdl.update == "13.2":
+        if self.config.use_floppy_autoyast:
             oz.ozutil.subprocess_check_output(["/sbin/mkfs.msdos", "-C",
                                                self.output_floppy, "1440"])
             oz.ozutil.subprocess_check_output(["mcopy", "-n", "-o", "-i",
@@ -89,7 +185,7 @@ class OpenSUSEGuest(oz.Linux.LinuxCDGuest):
                 lines[index] = "default customiso\n"
         lines.append("label customiso\n")
         lines.append("  kernel linux\n")
-        if self.tdl.update == "13.2":
+        if self.config.use_floppy_autoyast:
             # OpenSUSE 13.2 has an utterly broken autoyast that can't figure out
             # how to read the autoinst.xml from the CD.  Use a floppy instead.
             lines.append("  append initrd=initrd splash=silent autoyast=floppy:///autoinst.xml")
@@ -121,9 +217,9 @@ class OpenSUSEGuest(oz.Linux.LinuxCDGuest):
         Method to run the operating system installation.
         """
         extrainstalldevs = None
-        if self.tdl.update == "13.2":
+        if self.config.use_floppy_autoyast:
             extrainstalldevs = [self._InstallDev("floppy", self.output_floppy, "fda")]
-        return self._do_install(timeout, force, self.reboots, None, None, None, extrainstalldevs)
+        return self._do_install(timeout, force, self.config.reboots, None, None, None, extrainstalldevs)
 
     def _image_ssh_teardown_step_1(self, g_handle):
         """
@@ -226,9 +322,9 @@ class OpenSUSEGuest(oz.Linux.LinuxCDGuest):
         XML.
         """
         self.log.debug("Generating ICICLE")
-        stdout, stderr, retcode = self.guest_execute_command(guestaddr,
-                                                             'rpm -qa',
-                                                             timeout=30)
+        stdout, stderr_unused, retcode_unused = self.guest_execute_command(guestaddr,
+                                                                           'rpm -qa',
+                                                                           timeout=30)
 
         return self._output_icicle_xml(stdout.split("\n"),
                                        self.tdl.description)
@@ -317,7 +413,7 @@ fi
             try:
                 g_handle.upload(scriptfile,
                                 '/etc/NetworkManager/dispatcher.d/99-reportip')
-                g_handle.chmod(0755,
+                g_handle.chmod(0o755,
                                '/etc/NetworkManager/dispatcher.d/99-reportip')
             finally:
                 os.unlink(scriptfile)
@@ -411,15 +507,15 @@ echo -n "!$ADDR,%s!" > /dev/ttyS1
     def _install_packages(self, guestaddr, packstr):
         # due to a bug in OpenSUSE 11.1, we want to remove the default
         # CD repo first
-        stdout, stderr, retcode = self.guest_execute_command(guestaddr,
-                                                             'zypper repos -d')
+        stdout, stderr_unused, retcode_unused = self.guest_execute_command(guestaddr,
+                                                                           'zypper repos -d')
         removerepos = []
         for line in stdout.split('\n'):
             if re.match("^[0-9]+", line):
                 split = line.split('|')
 
                 column = 7
-                if self.tdl.update in ["42.1", "42.2"]:
+                if self.config.extended_zypper_list:
                     # OpenSUSE Leap has the URI in the 8th column
                     column = 8
                 if re.match("^cd://", split[column].strip()):
@@ -438,25 +534,19 @@ echo -n "!$ADDR,%s!" > /dev/ttyS1
                 self.guest_execute_command(guestaddr,
                                            "zypper removerepo %s" % (repo.name))
 
+
 def get_class(tdl, config, auto, output_disk=None, netdev=None, diskbus=None,
               macaddress=None):
     """
     Factory method for OpenSUSE installs.
     """
-    if tdl.update in ["10.3"]:
-        return OpenSUSEGuest(tdl, config, auto, output_disk, netdev, diskbus,
-                             macaddress)
-    if tdl.update in ["11.0", "11.1", "11.2", "11.3", "11.4", "12.1", "12.2",
-                      "12.3", "13.1", "13.2", "42.1", "42.2"]:
-        if diskbus is None:
-            diskbus = 'virtio'
-        if netdev is None:
-            netdev = 'virtio'
+    if tdl.update in version_to_config.keys():
         return OpenSUSEGuest(tdl, config, auto, output_disk, netdev, diskbus,
                              macaddress)
 
+
 def get_supported_string():
     """
     Return supported versions as a string.
     """
-    return "OpenSUSE: 10.3, 11.0, 11.1, 11.2, 11.3, 11.4, 12.1, 12.2, 12.3, 13.1, 13.2, 42.1, 42.2"
+    return "OpenSUSE: " + ", ".join(sorted(version_to_config.keys()))
