@@ -1,5 +1,5 @@
 # Copyright (C) 2010,2011  Chris Lalancette <clalance@redhat.com>
-# Copyright (C) 2012-2016  Chris Lalancette <clalancette@gmail.com>
+# Copyright (C) 2012-2017  Chris Lalancette <clalancette@gmail.com>
 
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -19,8 +19,11 @@
 RHEL-2.1 installation
 """
 
-import oz.RedHat
 import oz.OzException
+import oz.RedHat
+
+versions = ["GOLD", "U2", "U3", "U4", "U5", "U6"]
+
 
 class RHEL21Guest(oz.RedHat.RedHatFDGuest):
     """
@@ -37,19 +40,21 @@ class RHEL21Guest(oz.RedHat.RedHatFDGuest):
         """
         return oz.ozutil.generate_full_auto_path("RHEL2.1.auto")
 
+
 def get_class(tdl, config, auto, output_disk=None, netdev=None, diskbus=None,
               macaddress=None):
     """
     Factory method for RHEL-2.1 installs.
     """
-    if tdl.update in ["GOLD", "U2", "U3", "U4", "U5", "U6"]:
+    if tdl.update in versions:
         if netdev is None:
             netdev = 'pcnet'
         return RHEL21Guest(tdl, config, auto, output_disk, netdev, diskbus,
                            macaddress)
 
+
 def get_supported_string():
     """
     Return supported versions as a string.
     """
-    return "RHEL 2.1: GOLD, U2, U3, U4, U5, U6"
+    return "RHEL 2.1: " + ", ".join(versions)
