@@ -1,5 +1,5 @@
 # Copyright (C) 2010,2011  Chris Lalancette <clalance@redhat.com>
-# Copyright (C) 2012-2016  Chris Lalancette <clalancette@gmail.com>
+# Copyright (C) 2012-2017  Chris Lalancette <clalancette@gmail.com>
 
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -19,12 +19,52 @@
 RHEL-5 installation
 """
 
-import re
 import os
+import re
 
-import oz.ozutil
-import oz.RedHat
 import oz.OzException
+import oz.RedHat
+import oz.ozutil
+
+
+class RHEL5Configuration(object):
+    """
+    Configuration class for RHEL-5 installation.
+    """
+    def __init__(self, default_netdev, default_diskbus):
+        self._default_netdev = default_netdev
+        self._default_diskbus = default_diskbus
+
+    @property
+    def default_netdev(self):
+        """
+        Property method for the default netdev for this version of RHEL-5.
+        """
+        return self._default_netdev
+
+    @property
+    def default_diskbus(self):
+        """
+        Property method for the default diskbus for this version of RHEL-5.
+        """
+        return self._default_diskbus
+
+
+version_to_config = {
+    "U11": RHEL5Configuration(default_netdev='virtio', default_diskbus='virtio'),
+    "U10": RHEL5Configuration(default_netdev='virtio', default_diskbus='virtio'),
+    "U9": RHEL5Configuration(default_netdev='virtio', default_diskbus='virtio'),
+    "U8": RHEL5Configuration(default_netdev='virtio', default_diskbus='virtio'),
+    "U7": RHEL5Configuration(default_netdev='virtio', default_diskbus='virtio'),
+    "U6": RHEL5Configuration(default_netdev='virtio', default_diskbus='virtio'),
+    "U5": RHEL5Configuration(default_netdev='virtio', default_diskbus='virtio'),
+    "U4": RHEL5Configuration(default_netdev='virtio', default_diskbus='virtio'),
+    "U3": RHEL5Configuration(default_netdev=None, default_diskbus=None),
+    "U2": RHEL5Configuration(default_netdev=None, default_diskbus=None),
+    "U1": RHEL5Configuration(default_netdev=None, default_diskbus=None),
+    "GOLD": RHEL5Configuration(default_netdev=None, default_diskbus=None),
+}
+
 
 class RHEL5Guest(oz.RedHat.RedHatLinuxCDYumGuest):
     """
@@ -32,6 +72,11 @@ class RHEL5Guest(oz.RedHat.RedHatLinuxCDYumGuest):
     """
     def __init__(self, tdl, config, auto, nicmodel, diskbus, output_disk=None,
                  macaddress=None):
+        self.config = version_to_config[tdl.update]
+        if nicmodel is None:
+            nicmodel = self.config.default_netdev
+        if diskbus is None:
+            diskbus = self.config.default_diskbus
         oz.RedHat.RedHatLinuxCDYumGuest.__init__(self, tdl, config, auto,
                                                  output_disk, nicmodel, diskbus,
                                                  True, True, "cpio", macaddress,
@@ -45,9 +90,9 @@ class RHEL5Guest(oz.RedHat.RedHatLinuxCDYumGuest):
 
         initrdline = "  append initrd=initrd.img ks=cdrom:/ks.cfg method="
         if self.tdl.installtype == "url":
-            initrdline += self.url + "\n"
+            initrdline += self.url
         else:
-            initrdline += "cdrom:/dev/cdrom\n"
+            initrdline += "cdrom:/dev/cdrom"
         self._modify_isolinux(initrdline)
 
     def _check_pvd(self):
@@ -66,7 +111,7 @@ class RHEL5Guest(oz.RedHat.RedHatLinuxCDYumGuest):
 
         if self.tdl.distro == "RHEL-5":
             if self.tdl.installtype == 'iso':
-                if not re.match(r"RHEL/5(\.[0-9])? " + self.tdl.arch + " DVD",
+                if not re.match(r"RHEL/5(\.[0-9]{1,2})? " + self.tdl.arch + " DVD",
                                 pvd.volume_identifier):
                     raise oz.OzException.OzException("Only DVDs are supported for RHEL-5 ISO installs")
             else:
@@ -79,7 +124,7 @@ class RHEL5Guest(oz.RedHat.RedHatLinuxCDYumGuest):
                 # unfortunately CentOS-5 has the same volume identifier for both
                 # DVDs and CDs.  To tell them apart, we assume that if the
                 # size is smaller than 1GB, this is a CD
-                if not re.match(r"CentOS_5.[0-9]_Final", pvd.volume_identifier) or (pvd.space_size * 2048) < 1 * 1024 * 1024 * 1024:
+                if not re.match(r"CentOS_5.[0-9]{1,2}_Final", pvd.volume_identifier) or (pvd.space_size * 2048) < 1 * 1024 * 1024 * 1024:
                     raise oz.OzException.OzException("Only DVDs are supported for CentOS-5 ISO installs")
             else:
                 # url installs
@@ -88,7 +133,7 @@ class RHEL5Guest(oz.RedHat.RedHatLinuxCDYumGuest):
         elif self.tdl.distro == "SLC-5":
             # SLC-5
             if self.tdl.installtype == 'iso':
-                if not re.match(r"Scientific Linux CERN 5.[0-9]", pvd.volume_identifier):
+                if not re.match(r"Scientific Linux CERN 5.[0-9]{1,2}", pvd.volume_identifier):
                     raise oz.OzException.OzException("Only DVDs are supported for SLC-5 ISO installs")
             else:
                 # url installs
@@ -101,24 +146,19 @@ class RHEL5Guest(oz.RedHat.RedHatLinuxCDYumGuest):
         """
         return oz.ozutil.generate_full_auto_path("RHEL5.auto")
 
+
 def get_class(tdl, config, auto, output_disk=None, netdev=None, diskbus=None,
               macaddress=None):
     """
     Factory method for RHEL-5 installs.
     """
-    if tdl.update in ["GOLD", "U1", "U2", "U3"]:
-        return RHEL5Guest(tdl, config, auto, netdev, diskbus, output_disk,
-                          macaddress)
-    if tdl.update in ["U4", "U5", "U6", "U7", "U8", "U9", "U10", "U11"]:
-        if netdev is None:
-            netdev = 'virtio'
-        if diskbus is None:
-            diskbus = 'virtio'
+    if tdl.update in version_to_config.keys():
         return RHEL5Guest(tdl, config, auto, netdev, diskbus, output_disk,
                           macaddress)
 
+
 def get_supported_string():
     """
     Return supported versions as a string.
     """
-    return "RHEL/OL/CentOS/Scientific Linux{,CERN} 5: GOLD, U1, U2, U3, U4, U5, U6, U7, U8, U9, U10, U11"
+    return "RHEL/OL/CentOS/Scientific Linux{,CERN} 5: " + ", ".join(sorted(version_to_config.keys()))
