@@ -1,5 +1,5 @@
 # Copyright (C) 2010,2011  Chris Lalancette <clalance@redhat.com>
-# Copyright (C) 2012-2016  Chris Lalancette <clalancette@gmail.com>
+# Copyright (C) 2012-2017  Chris Lalancette <clalancette@gmail.com>
 
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -21,9 +21,10 @@ RHEL-6 installation
 
 import os
 
-import oz.ozutil
-import oz.RedHat
 import oz.OzException
+import oz.RedHat
+import oz.ozutil
+
 
 class RHEL6Guest(oz.RedHat.RedHatLinuxCDYumGuest):
     """
@@ -44,9 +45,7 @@ class RHEL6Guest(oz.RedHat.RedHatLinuxCDYumGuest):
 
         initrdline = "  append initrd=initrd.img ks=cdrom:/ks.cfg"
         if self.tdl.installtype == "url":
-            initrdline += " repo=" + self.url + "\n"
-        else:
-            initrdline += "\n"
+            initrdline += " repo=" + self.url
         self._modify_isolinux(initrdline)
 
     def get_auto_path(self):
@@ -55,6 +54,7 @@ class RHEL6Guest(oz.RedHat.RedHatLinuxCDYumGuest):
         """
         return oz.ozutil.generate_full_auto_path("RHEL6.auto")
 
+
 def get_class(tdl, config, auto, output_disk=None, netdev=None, diskbus=None,
               macaddress=None):
     """
@@ -68,8 +68,9 @@ def get_class(tdl, config, auto, output_disk=None, netdev=None, diskbus=None,
         return RHEL6Guest(tdl, config, auto, output_disk, netdev, diskbus,
                           macaddress)
 
+
 def get_supported_string():
     """
     Return supported versions as a string.
     """
-    return "RHEL/OL/CentOS/Scientific Linux{,CERN} 6: 0, 1, 2, 3, 4, 5, 6, 7, 8"
+    return "RHEL/OL/CentOS/Scientific Linux{,CERN} 6"
