@@ -19,20 +19,21 @@
 Common methods for installing and configuring RedHat-based guests
 """
 
-import re
-import os
-import shutil
 try:
     import configparser
 except ImportError:
     import ConfigParser as configparser
 import gzip
+import os
+import re
+import shutil
 
 import oz.Guest
 import oz.GuestFSManager
 import oz.Linux
-import oz.ozutil
 import oz.OzException
+import oz.ozutil
+
 
 class RedHatLinuxCDGuest(oz.Linux.LinuxCDGuest):
     """
@@ -108,6 +109,10 @@ Subsystem	sftp	/usr/libexec/openssh/sftp-server
         Method to modify the isolinux.cfg file on a RedHat style CD.
         """
         self.log.debug("Modifying isolinux.cfg")
+        # append additional kernel params from the TDL to initrdline
+        if self.tdl.kernel_param:
+            initrdline += " " + self.tdl.kernel_param
+        initrdline += '\n'
         isolinuxcfg = os.path.join(self.iso_contents, "isolinux",
                                    "isolinux.cfg")
 
@@ -135,8 +140,7 @@ label customiso
                 """
                 if re.match("^rootpw", line):
                     return "rootpw " + self.rootpw + '\n'
-                else:
-                    return line
+                return line
 
             oz.ozutil.copy_modify_file(self.auto, outname, _kssub)
         else:
@@ -155,7 +159,7 @@ label customiso
             if re.match('# chkconfig:', line):
                 try:
                     startlevel = line.split(':')[1].split()[1]
-                except:
+                except Exception:
                     pass
                 break
 
@@ -335,6 +339,8 @@ label customiso
 
         if self.tdl.arch in ['ppc64', 'ppc64le']:
             announce_device = '/dev/hvc1'
+        elif self.tdl.arch == 's390x':
+            announce_device = '/dev/sclp_line0'
         else:
             announce_device = '/dev/ttyS1'
 
@@ -345,7 +351,7 @@ label customiso
                 f.write("""\
 #!/bin/bash
 
-if [ "$1" = "eth0" -a "$2" = "up" ]; then
+if [ "$1" != "lo" -a "$2" = "up" ]; then
     echo -n "!$DHCP4_IP_ADDRESS,%s!" > %s
 fi
 """ % (self.uuid, announce_device))
@@ -353,7 +359,7 @@ fi
             try:
                 g_handle.upload(scriptfile,
                                 '/etc/NetworkManager/dispatcher.d/99-reportip')
-                g_handle.chmod(0755,
+                g_handle.chmod(0o755,
                                '/etc/NetworkManager/dispatcher.d/99-reportip')
             finally:
                 os.unlink(scriptfile)
@@ -373,7 +379,7 @@ echo -n "!$ADDR,%s!" > %s
 
         try:
             g_handle.upload(scriptfile, '/root/reportip')
-            g_handle.chmod(0755, '/root/reportip')
+            g_handle.chmod(0o755, '/root/reportip')
         finally:
             os.unlink(scriptfile)
 
@@ -472,17 +478,17 @@ echo -n "!$ADDR,%s!" > %s
         XML.
         """
         self.log.debug("Generating ICICLE")
-        stdout, stderr, retcode = self.guest_execute_command(guestaddr,
-                                                             'rpm -qa',
-                                                             timeout=30)
+        stdout, stderr_unused, retcode_unused = self.guest_execute_command(guestaddr,
+                                                                           'rpm -qa',
+                                                                           timeout=30)
 
         package_split = stdout.split("\n")
 
         extrasplit = None
         if self.tdl.icicle_extra_cmd:
-            extrastdout, stderr, retcode = self.guest_execute_command(guestaddr,
-                                                                      self.tdl.icicle_extra_cmd,
-                                                                      timeout=30)
+            extrastdout, stderr_unused, retcode_unused = self.guest_execute_command(guestaddr,
+                                                                                    self.tdl.icicle_extra_cmd,
+                                                                                    timeout=30)
             extrasplit = extrastdout.split("\n")
 
             if len(package_split) != len(extrasplit):
@@ -491,6 +497,19 @@ echo -n "!$ADDR,%s!" > %s
         return self._output_icicle_xml(package_split, self.tdl.description,
                                        extrasplit)
 
+    def _parse_treeinfo(self, fp):
+        """
+        Internal method to parse the treeinfo file and get the kernel and
+        initrd paths out of it.
+        """
+        self.log.debug("Got treeinfo, parsing")
+        config = configparser.SafeConfigParser()
+        config.readfp(fp)
+        section = "images-%s" % (self.tdl.arch)
+        kernel = oz.ozutil.config_get_key(config, section, "kernel", None)
+        initrd = oz.ozutil.config_get_key(config, section, "initrd", None)
+        return (kernel, initrd)
+
     def _get_kernel_from_treeinfo(self, fetchurl):
         """
         Internal method to download and parse the .treeinfo file from a URL.  If
@@ -517,13 +536,8 @@ echo -n "!$ADDR,%s!" > %s
 
             # if we made it here, the .treeinfo existed.  Parse it and
             # find out the location of the vmlinuz and initrd
-            self.log.debug("Got treeinfo, parsing")
-            os.lseek(treeinfofd, 0, os.SEEK_SET)
-            config = configparser.SafeConfigParser()
-            config.readfp(fp)
-            section = "images-%s" % (self.tdl.arch)
-            kernel = oz.ozutil.config_get_key(config, section, "kernel", None)
-            initrd = oz.ozutil.config_get_key(config, section, "initrd", None)
+            fp.seek(0)
+            (kernel, initrd) = self._parse_treeinfo(fp)
         finally:
             fp.close()
 
@@ -589,7 +603,7 @@ echo -n "!$ADDR,%s!" > %s
         initrd = None
         try:
             (kernel, initrd) = self._get_kernel_from_treeinfo(fetchurl)
-        except:
+        except Exception:
             pass
 
         if kernel is None:
@@ -684,14 +698,14 @@ echo -n "!$ADDR,%s!" > %s
         for fname in [self.output_iso, self.initrdfname, self.kernelfname]:
             try:
                 os.unlink(fname)
-            except:
+            except Exception:
                 pass
 
         if not self.cache_original_media:
             for fname in [self.orig_iso, self.kernelcache, self.initrdcache]:
                 try:
                     os.unlink(fname)
-                except:
+                except Exception:
                     pass
 
     def install(self, timeout=None, force=False):
@@ -702,6 +716,7 @@ echo -n "!$ADDR,%s!" > %s
                                 self.initrdfname, self.cmdline, None,
                                 self.virtio_channel_name)
 
+
 class RedHatLinuxCDYumGuest(RedHatLinuxCDGuest):
     """
     Class for RedHat-based CD guests with yum support.
@@ -824,6 +839,7 @@ class RedHatLinuxCDYumGuest(RedHatLinuxCDGuest):
                 self.guest_execute_command(guestaddr, "rm -f " + filename,
                                            timeout=30)
 
+
 class RedHatFDGuest(oz.Guest.FDGuest):
     """
     Class for RedHat-based floppy guests.
@@ -856,8 +872,7 @@ class RedHatFDGuest(oz.Guest.FDGuest):
                     return "url --url " + self.url + "\n"
                 elif re.match("^rootpw", line):
                     return "rootpw " + self.rootpw + "\n"
-                else:
-                    return line
+                return line
 
             oz.ozutil.copy_modify_file(self.auto, output_ks, _kssub)
         else:
