@@ -1,5 +1,5 @@
 # Copyright (C) 2010,2011  Chris Lalancette <clalance@redhat.com>
-# Copyright (C) 2012-2016  Chris Lalancette <clalancette@gmail.com>
+# Copyright (C) 2012-2018  Chris Lalancette <clalancette@gmail.com>
 
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -22,20 +22,23 @@ Template Description Language (TDL)
 import base64
 import os
 import re
+import sys
 import tempfile
 try:
     import urllib.parse as urlparse
 except ImportError:
     import urlparse
+
 try:
-    import StringIO
+    from StringIO import StringIO
 except ImportError:
     from io import StringIO
 
 import lxml.etree
 
-import oz.ozutil
 import oz.OzException
+import oz.ozutil
+
 
 def _xml_get_value(doc, xmlstring, component, optional=False):
     """
@@ -56,7 +59,7 @@ def _xml_get_value(doc, xmlstring, component, optional=False):
     res = doc.xpath(xmlstring)
     if len(res) == 1:
         return res[0].text
-    elif len(res) == 0:
+    elif not res:
         if optional:
             return None
         else:
@@ -64,6 +67,7 @@ def _xml_get_value(doc, xmlstring, component, optional=False):
     else:
         raise oz.OzException.OzException("Expected 0 or 1 %s in TDL, saw %d" % (component, len(res)))
 
+
 def data_from_type(name, contenttype, content):
     '''
     A function to get data out of some content, possibly decoding it depending
@@ -76,14 +80,18 @@ def data_from_type(name, contenttype, content):
 
     out = tempfile.NamedTemporaryFile()
     if contenttype == 'raw':
-        out.write(content)
+        out.write(content.encode('utf-8'))
     elif contenttype == 'base64':
-        base64.decode(StringIO.StringIO(content), out)
+        if sys.version_info.major == 2:
+            out.write(base64.decodestring(content))
+        else:
+            out.write(base64.decodebytes(content.encode('utf-8')))
     elif contenttype == 'url':
         url = urlparse.urlparse(content)
         if url.scheme == "file":
             with open(url.netloc + url.path) as f:
-                out.write("".join(f.readlines()))
+                outstr = "".join(f.readlines())
+                out.write(outstr.encode('utf-8'))
         else:
             oz.ozutil.http_download_file(content, out.fileno(), False, None)
     else:
@@ -96,6 +104,7 @@ def data_from_type(name, contenttype, content):
 
     return out
 
+
 class Repository(object):
     """
     Class that represents a single repository to be used for installing
@@ -114,6 +123,7 @@ class Repository(object):
         self.persisted = persisted
         self.sslverify = sslverify
 
+
 class Package(object):
     """
     Class that represents a single package to be installed.
@@ -130,6 +140,7 @@ class Package(object):
         self.filename = filename
         self.args = args
 
+
 class ISOExtra(object):
     """
     Class that represents an extra element to add to an installation ISO.
@@ -144,6 +155,7 @@ class ISOExtra(object):
         self.source = source
         self.destination = destination
 
+
 class TDL(object):
     """
     Class that represents a parsed piece of TDL XML.  Objects of this kind
@@ -175,7 +187,7 @@ class TDL(object):
     """
     def __init__(self, xmlstring, rootpw_required=False):
         # open the XML document
-        tree = lxml.etree.parse(StringIO.StringIO(xmlstring))
+        tree = lxml.etree.parse(StringIO(xmlstring))
         tree.xinclude()
         self.doc = tree.getroot()
 
@@ -206,8 +218,8 @@ class TDL(object):
 
         self.arch = _xml_get_value(self.doc, '/template/os/arch',
                                    'OS architecture')
-        if self.arch not in ["i386", "x86_64", "ppc64", "ppc64le", "aarch64", "armv7l"]:
-            raise oz.OzException.OzException("Architecture must be one of 'i386, x86_64, ppc64, ppc64le, armv7l, or aarch64'")
+        if self.arch not in ["i386", "x86_64", "ppc64", "ppc64le", "aarch64", "armv7l", "s390x"]:
+            raise oz.OzException.OzException("Architecture must be one of 'i386, x86_64, ppc64, ppc64le, armv7l, aarch64, or s390x'")
 
         self.key = _xml_get_value(self.doc, '/template/os/key', 'OS key',
                                   optional=True)
@@ -304,7 +316,6 @@ class TDL(object):
                                            'custom kernel parameter',
                                            optional=True)
 
-
     def _parse_disksize(self):
         """
         Internal method to parse the disk size out of the TDL.
@@ -355,7 +366,7 @@ class TDL(object):
             content = ""
             if command.text:
                 content = command.text.strip()
-            if len(content) == 0:
+            if not content:
                 raise oz.OzException.OzException("Empty commands are not allowed")
 
             # since XML doesn't *guarantee* an order, the correct way to
@@ -379,7 +390,7 @@ class TDL(object):
             for pos, fp in tmp:
                 commands.append(fp)
         else:
-            tmp.sort(cmp=lambda x, y: cmp(x[0], y[0]))
+            tmp.sort(key=lambda x: x[0])
             order = 1
             for pos, fp in tmp:
                 if pos is None:
@@ -435,8 +446,8 @@ class TDL(object):
 
             if remove_duplicates:
                 # delete any existing packages with this name
-                for package in [package for package in self.packages if package.name == name]:
-                    self.packages.remove(package)
+                for p in [package for package in self.packages if package.name == name]:
+                    self.packages.remove(p)
 
             # now add in our new package def
             self.packages.append(Package(name, repo, filename, args))
