@@ -1,5 +1,5 @@
 # Copyright (C) 2010,2011  Chris Lalancette <clalance@redhat.com>
-# Copyright (C) 2012-2016  Chris Lalancette <clalancette@gmail.com>
+# Copyright (C) 2012-2018  Chris Lalancette <clalancette@gmail.com>
 
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -27,8 +27,9 @@ import shutil
 import lxml.etree
 
 import oz.Guest
-import oz.ozutil
 import oz.OzException
+import oz.ozutil
+
 
 class Windows(oz.Guest.CDGuest):
     """
@@ -43,6 +44,7 @@ class Windows(oz.Guest.CDGuest):
         if self.tdl.key is None:
             raise oz.OzException.OzException("A key is required when installing Windows")
 
+
 class Windows_v5(Windows):
     """
     Class for Windows versions based on kernel 5.x (2000, XP, and 2003).
@@ -91,7 +93,7 @@ class Windows_v5(Windows):
             # If given a blank diskimage, windows 2000 stops very early in
             # install with a message:
             #
-            #  Setup has determined that your computer's starupt hard disk is
+            #  Setup has determined that your computer's startup hard disk is
             #  new or has been erased...
             #
             # To avoid that message, create a partition table that spans
@@ -129,8 +131,7 @@ class Windows_v5(Windows):
                     return "    ComputerName=" + computername + "\n"
                 elif re.match(" *AdminPassword", line):
                     return "    AdminPassword=" + self.rootpw + "\n"
-                else:
-                    return line
+                return line
 
             oz.ozutil.copy_modify_file(self.auto, outname, _sifsub)
         else:
@@ -147,6 +148,7 @@ class Windows_v5(Windows):
             internal_timeout = 3600
         return self._do_install(internal_timeout, force, 1)
 
+
 class Windows_v6(Windows):
     """
     Class for Windows versions based on kernel 6.x (2008, 7, 2012, 8, and 8.1).
@@ -196,30 +198,29 @@ class Windows_v6(Windows):
             doc = lxml.etree.parse(self.auto)
 
             for component in doc.xpath('/ms:unattend/ms:settings/ms:component',
-                                       namespaces={'ms':'urn:schemas-microsoft-com:unattend'}):
+                                       namespaces={'ms': 'urn:schemas-microsoft-com:unattend'}):
                 component.set('processorArchitecture', self.winarch)
 
             keys = doc.xpath('/ms:unattend/ms:settings/ms:component/ms:ProductKey',
-                             namespaces={'ms':'urn:schemas-microsoft-com:unattend'})
+                             namespaces={'ms': 'urn:schemas-microsoft-com:unattend'})
             if len(keys) != 1:
                 raise oz.OzException.OzException("Invalid autounattend file; expected 1 key, saw %d" % (len(keys)))
             keys[0].text = self.tdl.key
 
             adminpw = doc.xpath('/ms:unattend/ms:settings/ms:component/ms:UserAccounts/ms:AdministratorPassword/ms:Value',
-                                namespaces={'ms':'urn:schemas-microsoft-com:unattend'})
+                                namespaces={'ms': 'urn:schemas-microsoft-com:unattend'})
             if len(adminpw) != 1:
                 raise oz.OzException.OzException("Invalid autounattend file; expected 1 admin password, saw %d" % (len(adminpw)))
             adminpw[0].text = self.rootpw
 
             autologinpw = doc.xpath('/ms:unattend/ms:settings/ms:component/ms:AutoLogon/ms:Password/ms:Value',
-                                    namespaces={'ms':'urn:schemas-microsoft-com:unattend'})
+                                    namespaces={'ms': 'urn:schemas-microsoft-com:unattend'})
             if len(autologinpw) != 1:
                 raise oz.OzException.OzException("Invalid autounattend file; expected 1 auto logon password, saw %d" % (len(autologinpw)))
             autologinpw[0].text = self.rootpw
 
-            f = open(outname, 'w')
-            f.write(lxml.etree.tostring(doc, pretty_print=True))
-            f.close()
+            with open(outname, 'w') as f:
+                f.write(lxml.etree.tostring(doc, pretty_print=True, encoding="unicode"))
         else:
             # if the user provided their own unattend file, do not override
             # their choices; the user gets to keep both pieces if something
@@ -232,6 +233,7 @@ class Windows_v6(Windows):
             internal_timeout = 8500
         return self._do_install(internal_timeout, force, 2)
 
+
 class Windows_v10(Windows):
     """
     Class for Windows versions based on kernel 10.x (2016 and 10).
@@ -279,30 +281,29 @@ class Windows_v10(Windows):
             doc = lxml.etree.parse(self.auto)
 
             for component in doc.xpath('/ms:unattend/ms:settings/ms:component',
-                                       namespaces={'ms':'urn:schemas-microsoft-com:unattend'}):
+                                       namespaces={'ms': 'urn:schemas-microsoft-com:unattend'}):
                 component.set('processorArchitecture', self.winarch)
 
             keys = doc.xpath('/ms:unattend/ms:settings/ms:component/ms:ProductKey',
-                             namespaces={'ms':'urn:schemas-microsoft-com:unattend'})
+                             namespaces={'ms': 'urn:schemas-microsoft-com:unattend'})
             if len(keys) != 1:
                 raise oz.OzException.OzException("Invalid autounattend file; expected 1 key, saw %d" % (len(keys)))
             keys[0].text = self.tdl.key
 
             adminpw = doc.xpath('/ms:unattend/ms:settings/ms:component/ms:UserAccounts/ms:AdministratorPassword/ms:Value',
-                                namespaces={'ms':'urn:schemas-microsoft-com:unattend'})
+                                namespaces={'ms': 'urn:schemas-microsoft-com:unattend'})
             if len(adminpw) != 1:
                 raise oz.OzException.OzException("Invalid autounattend file; expected 1 admin password, saw %d" % (len(adminpw)))
             adminpw[0].text = self.rootpw
 
             autologinpw = doc.xpath('/ms:unattend/ms:settings/ms:component/ms:AutoLogon/ms:Password/ms:Value',
-                                    namespaces={'ms':'urn:schemas-microsoft-com:unattend'})
+                                    namespaces={'ms': 'urn:schemas-microsoft-com:unattend'})
             if len(autologinpw) != 1:
                 raise oz.OzException.OzException("Invalid autounattend file; expected 1 auto logon password, saw %d" % (len(autologinpw)))
             autologinpw[0].text = self.rootpw
 
-            f = open(outname, 'w')
-            f.write(lxml.etree.tostring(doc, pretty_print=True))
-            f.close()
+            with open(outname, 'w') as f:
+                f.write(lxml.etree.tostring(doc, pretty_print=True, encoding="unicode"))
         else:
             # if the user provided their own unattend file, do not override
             # their choices; the user gets to keep both pieces if something
@@ -315,6 +316,7 @@ class Windows_v10(Windows):
             internal_timeout = 8500
         return self._do_install(internal_timeout, force, 2)
 
+
 def get_class(tdl, config, auto, output_disk=None, netdev=None, diskbus=None,
               macaddress=None):
     """
@@ -330,6 +332,7 @@ def get_class(tdl, config, auto, output_disk=None, netdev=None, diskbus=None,
         return Windows_v10(tdl, config, auto, output_disk, netdev, diskbus,
                            macaddress)
 
+
 def get_supported_string():
     """
     Return supported versions as a string.
