@@ -1,5 +1,5 @@
 # Copyright (C) 2010,2011  Chris Lalancette <clalance@redhat.com>
-# Copyright (C) 2012-2017  Chris Lalancette <clalancette@gmail.com>
+# Copyright (C) 2012-2018  Chris Lalancette <clalancette@gmail.com>
 
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -19,31 +19,35 @@
 Miscellaneous utility functions.
 """
 
-import os
-import random
-import subprocess
-import errno
-import stat
-import shutil
-import gzip
-import time
-import select
-import urllib
+import collections
 try:
     import configparser
 except ImportError:
     import ConfigParser as configparser
-import collections
-import ftplib
-import struct
+import errno
 import fcntl
+import ftplib
+import gzip
 import logging
+import os
+import random
+import select
+import shutil
 import socket
+import stat
+import struct
+import subprocess
+import sys
+import time
+import urllib
 
 import lxml.etree
+
 import monotonic
+
 import requests
 
+
 def generate_full_auto_path(relative):
     """
     Function to find the absolute path to an unattended installation file.
@@ -56,6 +60,7 @@ def generate_full_auto_path(relative):
     pkg_path = os.path.dirname(__file__)
     return os.path.abspath(os.path.join(pkg_path, "auto", relative))
 
+
 def executable_exists(program):
     """
     Function to find out whether an executable exists in the PATH
@@ -71,7 +76,7 @@ def executable_exists(program):
     if program is None:
         raise Exception("Invalid program name passed")
 
-    fpath, fname = os.path.split(program)
+    fpath, fname_unused = os.path.split(program)
     if fpath:
         if is_exe(program):
             return program
@@ -83,6 +88,7 @@ def executable_exists(program):
 
     raise Exception("Could not find %s" % (program))
 
+
 def write_bytes_to_fd(fd, buf):
     """
     Function to write all bytes in "buf" to "fd".  This handles both EINTR
@@ -106,6 +112,7 @@ def write_bytes_to_fd(fd, buf):
 
     return offset
 
+
 def read_bytes_from_fd(fd, num):
     """
     Function to read and return bytes from fd.  This handles the EINTR situation
@@ -126,6 +133,7 @@ def read_bytes_from_fd(fd, num):
 
     return ret
 
+
 def copyfile_sparse(src, dest):
     """
     Function to copy a file sparsely if possible.  The logic here is
@@ -149,23 +157,23 @@ def copyfile_sparse(src, dest):
     src_fd = os.open(src, os.O_RDONLY)
 
     try:
-        dest_fd = os.open(dest, os.O_WRONLY|os.O_CREAT|os.O_TRUNC)
+        dest_fd = os.open(dest, os.O_WRONLY | os.O_CREAT | os.O_TRUNC)
 
         try:
             sb = os.fstat(src_fd)
 
             # See io_blksize() in coreutils for an explanation of why 32*1024
-            buf_size = max(32*1024, sb.st_blksize)
+            buf_size = max(32 * 1024, sb.st_blksize)
 
             size = sb.st_size
             destlen = 0
             while size != 0:
                 buf = read_bytes_from_fd(src_fd, min(buf_size, size))
-                if len(buf) == 0:
+                if not buf:
                     break
 
                 buflen = len(buf)
-                if buf == '\0'*buflen:
+                if buf == '\0' * buflen:
                     os.lseek(dest_fd, buflen, os.SEEK_CUR)
                 else:
                     write_bytes_to_fd(dest_fd, buf)
@@ -180,6 +188,7 @@ def copyfile_sparse(src, dest):
     finally:
         os.close(src_fd)
 
+
 def bsd_split(line, digest_type):
     """
     Function to split a BSD-style checksum line into a filename and
@@ -218,13 +227,14 @@ def bsd_split(line, digest_type):
 
     return line, filename
 
+
 def sum_split(line, digest_bits):
     """
     Function to split a normal Linux checksum line into a filename and
     checksum.
     """
-    digest_hex_bytes = digest_bits / 4
-    min_digest_line_length = digest_hex_bytes + 2 + 1 # length of hex message digest + blank and binary indicator (2 bytes) + minimum file length (1 byte)
+    digest_hex_bytes = digest_bits // 4
+    min_digest_line_length = digest_hex_bytes + 2 + 1  # length of hex message digest + blank and binary indicator (2 bytes) + minimum file length (1 byte)
 
     min_length = min_digest_line_length
     if line[0] == '\\':
@@ -253,9 +263,6 @@ def sum_split(line, digest_bits):
     if line[current] != ' ' and line[current] != '*':
         return None, None
 
-    if line[current] == '*':
-        binary = True
-
     current += 1
 
     filename = line[current:]
@@ -266,10 +273,14 @@ def sum_split(line, digest_bits):
         # FIXME: a \0 is not allowed in the sum file format, but
         # string_escape allows it.  We'd probably have to implement our
         # own codec to fix this
-        filename = filename.decode('string_escape')
+        if sys.version_info.major == 2:
+            filename = filename.decode('string_escape')
+        else:
+            filename = filename.encode('utf-8').decode('unicode_escape')
 
     return hex_digest, filename
 
+
 def get_sum_from_file(sumfile, file_to_find, digest_bits, digest_type):
     """
     Function to get a checksum digest out of a checksum file given a
@@ -277,52 +288,51 @@ def get_sum_from_file(sumfile, file_to_find, digest_bits, digest_type):
     """
     retval = None
 
-    f = open(sumfile, 'r')
-    for line in f:
-        binary = False
+    with open(sumfile, 'r') as f:
+        for line in f:
+            # remove any leading whitespace
+            line = line.lstrip()
 
-        # remove any leading whitespace
-        line = line.lstrip()
+            # ignore blank lines
+            if not line:
+                continue
 
-        # ignore blank lines
-        if len(line) == 0:
-            continue
+            # ignore comment lines
+            if line[0] == '#':
+                continue
 
-        # ignore comment lines
-        if line[0] == '#':
-            continue
+            if line.startswith(digest_type):
+                # OK, if it starts with a string of ["MD5", "SHA1", "SHA256"], then
+                # this is a BSD-style sumfile
+                hex_digest, filename = bsd_split(line, digest_type)
+            else:
+                # regular sumfile
+                hex_digest, filename = sum_split(line, digest_bits)
 
-        if line.startswith(digest_type):
-            # OK, if it starts with a string of ["MD5", "SHA1", "SHA256"], then
-            # this is a BSD-style sumfile
-            hex_digest, filename = bsd_split(line, digest_type)
-        else:
-            # regular sumfile
-            hex_digest, filename = sum_split(line, digest_bits)
+            if hex_digest is None or filename is None:
+                continue
 
-        if hex_digest is None or filename is None:
-            continue
-
-        if filename == file_to_find:
-            retval = hex_digest
-            break
-
-    f.close()
+            if filename == file_to_find:
+                retval = hex_digest
+                break
 
     return retval
 
+
 def get_md5sum_from_file(sumfile, file_to_find):
     """
     Function to get an MD5 checksum out of a checksum file given a filename.
     """
     return get_sum_from_file(sumfile, file_to_find, 128, "MD5")
 
+
 def get_sha1sum_from_file(sumfile, file_to_find):
     """
     Function to get a SHA1 checksum out of a checksum file given a filename.
     """
     return get_sum_from_file(sumfile, file_to_find, 160, "SHA1")
 
+
 def get_sha256sum_from_file(sumfile, file_to_find):
     """
     Function to get a SHA256 checksum out of a checksum file given a
@@ -330,6 +340,7 @@ def get_sha256sum_from_file(sumfile, file_to_find):
     """
     return get_sum_from_file(sumfile, file_to_find, 256, "SHA256")
 
+
 def string_to_bool(instr):
     """
     Function to take a string and determine whether it is True, Yes, False,
@@ -347,6 +358,7 @@ def string_to_bool(instr):
         return True
     return None
 
+
 def generate_macaddress():
     """
     Function to generate a random MAC address.
@@ -355,6 +367,7 @@ def generate_macaddress():
            random.randint(0x00, 0xff), random.randint(0x00, 0xff)]
     return ':'.join(["%02x" % x for x in mac])
 
+
 class SubprocessException(Exception):
     """
     Class for subprocess exceptions.  In addition to a error message, it
@@ -364,6 +377,7 @@ class SubprocessException(Exception):
         Exception.__init__(self, msg)
         self.retcode = retcode
 
+
 def subprocess_check_output(*popenargs, **kwargs):
     """
     Function to call a subprocess and gather the output.
@@ -374,7 +388,7 @@ def subprocess_check_output(*popenargs, **kwargs):
         raise ValueError('stderr argument not allowed, it will be overridden.')
 
     printfn = None
-    if kwargs.has_key('printfn'):
+    if 'printfn' in kwargs:
         printfn = kwargs['printfn']
         del kwargs['printfn']
 
@@ -395,7 +409,7 @@ def subprocess_check_output(*popenargs, **kwargs):
         start = time.time()
         try:
             ready = poller.poll(1000)
-        except select.error, e:
+        except select.error as e:
             if e.args[0] == errno.EINTR:
                 continue
             raise
@@ -406,6 +420,7 @@ def subprocess_check_output(*popenargs, **kwargs):
                 if not data:
                     poller.unregister(fd)
                 else:
+                    data = data.decode('utf-8')
                     if printfn is not None:
                         printfn(data)
                     if fd == process.stdout.fileno():
@@ -423,6 +438,9 @@ def subprocess_check_output(*popenargs, **kwargs):
 
     tmpout, tmperr = process.communicate()
 
+    tmpout = tmpout.decode('utf-8')
+    tmperr = tmperr.decode('utf-8')
+
     stdout += tmpout
     stderr += tmperr
     if printfn is not None:
@@ -431,10 +449,11 @@ def subprocess_check_output(*popenargs, **kwargs):
 
     if retcode:
         cmd = ' '.join(*popenargs)
-        raise SubprocessException("'%s' failed(%d): %s" % (cmd, retcode, stderr+stdout), retcode)
+        raise SubprocessException("'%s' failed(%d): %s" % (cmd, retcode, stderr + stdout), retcode)
 
     return (stdout, stderr, retcode)
 
+
 def mkdir_p(path):
     """
     Function to make a directory and all intermediate directories as
@@ -457,6 +476,7 @@ def mkdir_p(path):
         if err.errno != errno.EEXIST or not os.path.isdir(path):
             raise
 
+
 def copytree_merge(src, dst, symlinks=False, ignore=None):
     """
     Function to copy an entire directory recursively. The functionality
@@ -494,14 +514,12 @@ def copytree_merge(src, dst, symlinks=False, ignore=None):
             errors.extend(err.args[0])
     try:
         shutil.copystat(src, dst)
-    except shutil.WindowsError:
-        # can't copy file access times on Windows
-        pass
     except OSError as why:
         errors.extend((src, dst, str(why)))
     if errors:
         raise shutil.Error(errors)
 
+
 def copy_modify_file(inname, outname, subfunc):
     """
     Function to copy a file from inname to outname, passing each line
@@ -527,6 +545,7 @@ def copy_modify_file(inname, outname, subfunc):
     infile.close()
     outfile.close()
 
+
 def write_cpio(inputdict, outputfile):
     """
     Function to write a CPIO archive in the "New ASCII Format".  The
@@ -584,7 +603,7 @@ def write_cpio(inputdict, outputfile):
             # header (110 bytes) plus the filename, plus the sentinel a
             # multiple of 4 bytes.  Note that we always need at *least* one NUL,
             # so if it is exactly a multiple of 4 we need to write 4 NULs
-            outf.write("\x00"*(4 - ((110+len(stripped)) % 4)))
+            outf.write("\x00" * (4 - ((110 + len(stripped)) % 4)))
 
             # now write the data from the input file
             outf.writelines(inf)
@@ -595,7 +614,7 @@ def write_cpio(inputdict, outputfile):
             # so if it is already aligned on 4 bytes do nothing
             remainder = st[stat.ST_SIZE] % 4
             if remainder != 0:
-                outf.write("\x00"*(4 - remainder))
+                outf.write("\x00" * (4 - remainder))
 
         # now that we have written all of the file entries, write the trailer
         outf.write("070701")
@@ -629,21 +648,22 @@ def write_cpio(inputdict, outputfile):
         outf.write("TRAILER!!!")
 
         # finally, we need to pad to the closest 512 bytes
-        outf.write("\x00"*(512 - (outf.tell() % 512)))
+        outf.write("\x00" * (512 - (outf.tell() % 512)))
     except:
         os.unlink(outputfile)
         raise
 
     outf.close()
 
+
 def config_get_key(config, section, key, default):
     """
     Function to retrieve config parameters out of the config file.
     """
     if config is not None and config.has_section(section) and config.has_option(section, key):
         return config.get(section, key)
-    else:
-        return default
+    return default
+
 
 def config_get_boolean_key(config, section, key, default):
     """
@@ -659,6 +679,7 @@ def config_get_boolean_key(config, section, key, default):
 
     return retval
 
+
 def config_get_path(config, section, key, default):
     """
     Function to get an user-expanded path out of the config file at
@@ -671,6 +692,7 @@ def config_get_path(config, section, key, default):
         raise Exception("Config key '%s' must have an absolute path" % (key))
     return path
 
+
 def rmtree_and_sync(directory):
     """
     Function to remove a directory tree and do an fsync afterwards.  Because
@@ -693,6 +715,7 @@ def rmtree_and_sync(directory):
         else:
             raise
 
+
 def parse_config(config_file):
     """
     Function to parse the configuration file.  If the passed in config_file is
@@ -711,19 +734,20 @@ def parse_config(config_file):
         # /etc/oz/oz.cfg.  If neither of those exist, we don't throw an error
         # but instead let Oz pick sane defaults internally.
         parsed = config.read(os.path.expanduser("~/.oz/oz.cfg"))
-        if len(parsed) == 0 and os.geteuid() == 0:
+        if not parsed and os.geteuid() == 0:
             config.read("/etc/oz/oz.cfg")
 
     return config
 
+
 def default_output_dir():
     """
     Function to get the default path to the output directory.
     """
     if os.geteuid() == 0:
         return "/var/lib/libvirt/images"
-    else:
-        return "~/.oz/images"
+    return "~/.oz/images"
+
 
 def default_data_dir():
     """
@@ -731,8 +755,8 @@ def default_data_dir():
     """
     if os.geteuid() == 0:
         return "/var/lib/oz"
-    else:
-        return "~/.oz"
+    return "~/.oz"
+
 
 def default_sshprivkey():
     """
@@ -740,8 +764,8 @@ def default_sshprivkey():
     """
     if os.geteuid() == 0:
         return "/etc/oz/id_rsa-icicle-gen"
-    else:
-        return "~/.oz/id_rsa-icicle-gen"
+    return "~/.oz/id_rsa-icicle-gen"
+
 
 def default_screenshot_dir():
     """
@@ -750,6 +774,7 @@ def default_screenshot_dir():
     """
     return os.path.join(default_data_dir(), "screenshots")
 
+
 class LocalFileAdapter(requests.adapters.BaseAdapter):
     '''
     This class implements an adapter for requests so we can properly deal with file://
@@ -759,7 +784,7 @@ class LocalFileAdapter(requests.adapters.BaseAdapter):
     def _chkpath(method, path):
         """Return an HTTP status for the given filesystem path."""
         if method.lower() in ('put', 'delete'):
-            return 501, "Not Implemented"  # TODO
+            return 501, "Not Implemented"
         elif method.lower() not in ('get', 'head', 'post'):
             return 405, "Method Not Allowed"
         elif os.path.isdir(path):
@@ -768,36 +793,38 @@ class LocalFileAdapter(requests.adapters.BaseAdapter):
             return 404, "File Not Found"
         elif not os.access(path, os.R_OK):
             return 403, "Access Denied"
-        else:
-            return 200, "OK"
+        return 200, "OK"
 
-    def send(self, req, **kwargs):
+    def send(self, request, stream=False, timeout=None, verify=True, cert=None, proxies=None):
         """Return the file specified by the given request
 
         @type req: C{PreparedRequest}
         @todo: Should I bother filling `response.headers` and processing
                If-Modified-Since and friends using `os.stat`?
         """
-        path = os.path.normcase(os.path.normpath(urllib.url2pathname(req.path_url)))
+        if sys.version_info.major == 2:
+            path = os.path.normcase(os.path.normpath(urllib.url2pathname(request.path_url)))  # pylint: disable=no-member
+        else:
+            path = os.path.normcase(os.path.normpath(urllib.request.url2pathname(request.path_url)))
         response = requests.Response()
 
-        response.status_code, response.reason = self._chkpath(req.method, path)
-        if response.status_code == 200 and req.method.lower() != 'head':
+        response.status_code, response.reason = self._chkpath(request.method, path)
+        if response.status_code == 200 and request.method.lower() != 'head':
             try:
                 response.raw = open(path, 'rb')
-            except (OSError, IOError), err:
+            except (OSError, IOError) as err:
                 response.status_code = 500
                 response.reason = str(err)
 
-        if isinstance(req.url, bytes):
-            response.url = req.url.decode('utf-8')
+        if isinstance(request.url, bytes):
+            response.url = request.url.decode('utf-8')
         else:
-            response.url = req.url
+            response.url = request.url
 
         response.headers['Content-Length'] = os.path.getsize(path)
         response.headers['Accept-Ranges'] = 'bytes'
-        response.headers['Redirect-URL'] = req.url
-        response.request = req
+        response.headers['Redirect-URL'] = request.url
+        response.request = request
         response.connection = self
 
         return response
@@ -805,6 +832,7 @@ class LocalFileAdapter(requests.adapters.BaseAdapter):
     def close(self):
         pass
 
+
 def http_get_header(url, redirect=True):
     """
     Function to get the HTTP headers from a URL.  The available headers will be
@@ -818,7 +846,7 @@ def http_get_header(url, redirect=True):
     """
     with requests.Session() as requests_session:
         requests_session.mount('file://', LocalFileAdapter())
-        response = requests_session.post(url, allow_redirects=redirect, stream=True, timeout=10)
+        response = requests_session.head(url, allow_redirects=redirect, stream=True, timeout=10)
         info = response.headers
         info['HTTP-Code'] = response.status_code
         if not redirect:
@@ -828,6 +856,7 @@ def http_get_header(url, redirect=True):
 
     return info
 
+
 def http_download_file(url, fd, show_progress, logger):
     """
     Function to download a file from url to file descriptor fd.
@@ -837,7 +866,7 @@ def http_download_file(url, fd, show_progress, logger):
         response = requests_session.get(url, stream=True, allow_redirects=True,
                                         headers={'Accept-Encoding': ''})
         file_size = int(response.headers.get('Content-Length'))
-        chunk_size = 10*1024*1024
+        chunk_size = 10 * 1024 * 1024
         done = 0
         for chunk in response.iter_content(chunk_size):
             write_bytes_to_fd(fd, chunk)
@@ -845,11 +874,13 @@ def http_download_file(url, fd, show_progress, logger):
             if show_progress:
                 logger.debug("%dkB of %dkB" % (done / 1024, file_size / 1024))
 
-def ftp_download_directory(server, username, password, basepath, destination):
+
+def ftp_download_directory(server, username, password, basepath, destination, port=None):
     """
     Function to recursively download an entire directory structure over FTP.
     """
-    ftp = ftplib.FTP(server)
+    ftp = ftplib.FTP()
+    ftp.connect(server, port)
     ftp.login(username, password)
 
     def _recursive_ftp_download(sourcepath):
@@ -876,6 +907,7 @@ def ftp_download_directory(server, username, password, basepath, destination):
     _recursive_ftp_download(basepath)
     ftp.close()
 
+
 def _gzip_file(inputfile, outputfile, outputmode):
     """
     Internal function to gzip the input file and place it in the outputfile.
@@ -888,12 +920,14 @@ def _gzip_file(inputfile, outputfile, outputmode):
         gzf.writelines(f)
         gzf.close()
 
+
 def gzip_append(inputfile, outputfile):
     """
     Function to gzip and append the data from inputfile onto output file.
     """
     _gzip_file(inputfile, outputfile, 'ab')
 
+
 def gzip_create(inputfile, outputfile):
     """
     Function to gzip the data from inputfile and place it into outputfile,
@@ -907,6 +941,7 @@ def gzip_create(inputfile, outputfile):
             os.unlink(outputfile)
         raise
 
+
 def check_qcow_size(filename):
     """
     Function to detect if an image is in qcow format.  If it is, return the size
@@ -931,8 +966,8 @@ def check_qcow_size(filename):
     # };
 
     # And in Python struct format string-ese
-    qcow_struct = ">IIQIIQIIQQIIQ" # > means big-endian
-    qcow_magic = 0x514649FB # 'Q' 'F' 'I' 0xFB
+    qcow_struct = ">IIQIIQIIQQIIQ"  # > means big-endian
+    qcow_magic = 0x514649FB  # 'Q' 'F' 'I' 0xFB
 
     f = open(filename, "r")
     pack = f.read(struct.calcsize(qcow_struct))
@@ -942,8 +977,8 @@ def check_qcow_size(filename):
 
     if unpack[0] == qcow_magic:
         return unpack[5]
-    else:
-        return None
+    return None
+
 
 def recursively_add_write_bit(inputdir):
     """
@@ -952,7 +987,7 @@ def recursively_add_write_bit(inputdir):
     files extracted from an ISO, since those were all read-only to begin
     with.
     """
-    for dirpath, dirnames, filenames in os.walk(inputdir):
+    for dirpath, dirnames_unused, filenames in os.walk(inputdir):
         # If the path is a symlink, and it is an absolute symlink, this would
         # attempt to change the permissions of the *host* file, not the
         # file that is relative to here.  That is no good, and could be a
@@ -961,7 +996,7 @@ def recursively_add_write_bit(inputdir):
         if os.path.islink(dirpath):
             continue
 
-        os.chmod(dirpath, os.stat(dirpath).st_mode|stat.S_IWUSR)
+        os.chmod(dirpath, os.stat(dirpath).st_mode | stat.S_IWUSR)
         for name in filenames:
             fullpath = os.path.join(dirpath, name)
 
@@ -973,11 +1008,12 @@ def recursively_add_write_bit(inputdir):
                 # if there are broken symlinks in the ISO,
                 # then the below might fail.  This probably
                 # isn't fatal, so just allow it and go on
-                os.chmod(fullpath, os.stat(fullpath).st_mode|stat.S_IWUSR)
+                os.chmod(fullpath, os.stat(fullpath).st_mode | stat.S_IWUSR)
             except OSError as err:
                 if err.errno != errno.ENOENT:
                     raise
 
+
 def find_uefi_firmware(arch):
     '''
     A function to find the UEFI firmware file that corresponds to a certain
@@ -1032,6 +1068,7 @@ def find_uefi_firmware(arch):
 
     raise Exception("UEFI firmware is not installed!")
 
+
 def open_locked_file(filename):
     """
     A function to open and lock a file.  Returns a file descriptor referencing
@@ -1040,7 +1077,7 @@ def open_locked_file(filename):
     outdir = os.path.dirname(filename)
     mkdir_p(outdir)
 
-    fd = os.open(filename, os.O_RDWR|os.O_CREAT)
+    fd = os.open(filename, os.O_RDWR | os.O_CREAT)
 
     try:
         fcntl.lockf(fd, fcntl.LOCK_EX)
@@ -1050,6 +1087,7 @@ def open_locked_file(filename):
 
     return (fd, outdir)
 
+
 def lxml_subelement(root, name, text=None, attributes=None):
     """
     Function to add a new element to an LXML tree, optionally include text
@@ -1063,6 +1101,7 @@ def lxml_subelement(root, name, text=None, attributes=None):
             tmp.set(k, v)
     return tmp
 
+
 def timed_loop(max_time, cb, msg, cb_arg=None):
     '''
     A function to deal with waiting for an event to occur.  Given a
@@ -1086,7 +1125,10 @@ def timed_loop(max_time, cb, msg, cb_arg=None):
     while now < end:
         now = monotonic.monotonic()
         if now >= next_print:
-            log.debug("%s, %d/%d", msg, int(end) - int(now), max_time)
+            left = int(end) - int(now)
+            if left < 0:
+                left = 0
+            log.debug("%s, %d/%d", msg, left, max_time)
             next_print = now + 10
 
             if cb(cb_arg):
@@ -1104,6 +1146,7 @@ def timed_loop(max_time, cb, msg, cb_arg=None):
 
     return False
 
+
 def get_free_port():
     """
     A function to find a free TCP port on the host.
