@@ -7,10 +7,9 @@ try:
 except ImportError:
     import ConfigParser as configparser
 try:
-    from io import StringIO, BytesIO
-except:
     from StringIO import StringIO
-    BytesIO = StringIO
+except:
+    from io import StringIO
 import logging
 import os
 
@@ -39,7 +38,7 @@ except ImportError:
 
 def default_route():
     route_file = "/proc/net/route"
-    d = file(route_file)
+    d = open(route_file)
 
     defn = 0
     for line in d:
@@ -65,7 +64,7 @@ def setup_guest(xml, macaddress=None):
     tdl = oz.TDL.TDL(xml)
 
     config = configparser.SafeConfigParser()
-    config.readfp(BytesIO("[libvirt]\nuri=qemu:///session\nbridge_name=%s" % route))
+    config.readfp(StringIO("[libvirt]\nuri=qemu:///session\nbridge_name=%s" % route))
 
     guest = oz.GuestFactory.guest_factory(tdl, config, None, macaddress=macaddress)
     return guest
@@ -356,7 +355,7 @@ def test_init_guest_bad_arch():
     tdl = oz.TDL.TDL(tdlxml)
     tdl.arch = 'armhf'  # Done here to make sure the TDL class doesn't error
     config = configparser.SafeConfigParser()
-    config.readfp(BytesIO("[libvirt]\nuri=qemu:///session\nbridge_name=%s" % route))
+    config.readfp(StringIO("[libvirt]\nuri=qemu:///session\nbridge_name=%s" % route))
     with py.test.raises(Exception):
         oz.GuestFactory.guest_factory(tdl, config, None)
 
