@@ -26,7 +26,7 @@ except ImportError:
 
 # test oz.ozutil.generate_full_auto_path
 def test_auto():
-    oz.ozutil.generate_full_auto_path('fedora-14-jeos.ks')
+    assert(oz.ozutil.generate_full_auto_path('fedora-14-jeos.ks') == os.path.realpath(os.path.join(prefix, 'oz', 'auto', 'fedora-14-jeos.ks')))
 
 def test_auto_none():
     with py.test.raises(Exception):
@@ -34,7 +34,7 @@ def test_auto_none():
 
 # test oz.ozutil.executable_exists
 def test_exe_exists_bin_ls():
-    oz.ozutil.executable_exists('/bin/ls')
+    assert(oz.ozutil.executable_exists('/bin/ls'))
 
 def test_exe_exists_foo():
     with py.test.raises(Exception):
@@ -49,7 +49,7 @@ def test_exe_exists_not_x():
         oz.ozutil.executable_exists('/etc/hosts')
 
 def test_exe_exists_relative_false():
-    oz.ozutil.executable_exists('false')
+    assert(oz.ozutil.executable_exists('false'))
 
 def test_exe_exists_none():
     with py.test.raises(Exception):
@@ -96,57 +96,56 @@ def test_copy_sparse_zero_size_src(tmpdir):
     fd.close()
     dstname = os.path.join(str(tmpdir), 'dst')
     oz.ozutil.copyfile_sparse(srcname, dstname)
+    assert(os.stat(dstname).st_size == 0)
 
 def test_copy_sparse_small_src(tmpdir):
     srcname = os.path.join(str(tmpdir), 'src')
     open(srcname, 'w').write('src')
     dstname = os.path.join(str(tmpdir), 'dst')
     oz.ozutil.copyfile_sparse(srcname, dstname)
+    assert(os.stat(dstname).st_size == 3)
 
 def test_copy_sparse_one_block_src(tmpdir):
-    infd = open('/dev/urandom', 'r')
-    # we read 32*1024 to make sure we use one big buf_size block (see the
-    # implementation of copyfile_sparse)
-    data = infd.read(32*1024)
-    infd.close
+    with open('/dev/urandom', 'rb') as infd:
+        # we read 32*1024 to make sure we use one big buf_size block (see the
+        # implementation of copyfile_sparse)
+        data = infd.read(32*1024)
 
     srcname = os.path.join(str(tmpdir), 'src')
-    outfd = open(srcname, 'w')
-    outfd.write(data)
-    outfd.close()
+    with open(srcname, 'wb') as outfd:
+        outfd.write(data)
     dstname = os.path.join(str(tmpdir), 'dst')
     oz.ozutil.copyfile_sparse(srcname, dstname)
+    assert(os.stat(dstname).st_size == 32*1024)
 
 def test_copy_sparse_many_blocks_src(tmpdir):
-    infd = open('/dev/urandom', 'r')
-    # we read 32*1024 to make sure we use one big buf_size block (see the
-    # implementation of copyfile_sparse)
-    data = infd.read(32*1024*10)
-    infd.close
+    with open('/dev/urandom', 'rb') as infd:
+        # we read 32*1024 to make sure we use one big buf_size block (see the
+        # implementation of copyfile_sparse)
+        data = infd.read(32*1024*10)
 
     srcname = os.path.join(str(tmpdir), 'src')
-    outfd = open(srcname, 'w')
-    outfd.write(data)
-    outfd.close()
+    with open(srcname, 'wb') as outfd:
+        outfd.write(data)
     dstname = os.path.join(str(tmpdir), 'dst')
     oz.ozutil.copyfile_sparse(srcname, dstname)
+    assert(os.stat(dstname).st_size == 32*1024*10)
 
 def test_copy_sparse_zero_blocks(tmpdir):
-    infd = open('/dev/urandom', 'r')
-    # we read 32*1024 to make sure we use one big buf_size block (see the
-    # implementation of copyfile_sparse)
-    data1 = infd.read(32*1024)
-    data2 = infd.read(32*1024)
-    infd.close
+    with open('/dev/urandom', 'rb') as infd:
+        # we read 32*1024 to make sure we use one big buf_size block (see the
+        # implementation of copyfile_sparse)
+        data1 = infd.read(32*1024)
+        data2 = infd.read(32*1024)
 
     srcname = os.path.join(str(tmpdir), 'src')
-    outfd = open(srcname, 'w')
-    outfd.write(data1)
-    outfd.write('\0'*32*1024)
-    outfd.write(data2)
-    outfd.close()
+    with open(srcname, 'wb') as outfd:
+        outfd.write(data1)
+        outfd.write(b'\0'*32*1024)
+        outfd.write(data2)
     dstname = os.path.join(str(tmpdir), 'dst')
     oz.ozutil.copyfile_sparse(srcname, dstname)
+    assert(os.stat(dstname).st_size == 32*1024*3)
 
 def test_copy_sparse_src_not_exists(tmpdir):
     srcname = os.path.join(str(tmpdir), 'src')
@@ -160,6 +159,7 @@ def test_copy_sparse_dest_not_exists(tmpdir):
     open(srcname, 'w').write('src')
     dstname = os.path.join(str(tmpdir), 'dst')
     oz.ozutil.copyfile_sparse(srcname, dstname)
+    assert(os.stat(dstname).st_size == 3)
 
 def test_copy_sparse_src_is_dir(tmpdir):
     dstname = os.path.join(str(tmpdir), 'dst')
@@ -178,7 +178,7 @@ def test_stb_no():
     for nletter in ['n', 'N']:
         for oletter in ['o', 'O']:
             curr = nletter+oletter
-            yield ('bool-'+curr, oz.ozutil.string_to_bool, curr)
+            assert(oz.ozutil.string_to_bool(curr) == False)
 
 def test_stb_false():
     for fletter in ['f', 'F']:
@@ -187,14 +187,14 @@ def test_stb_false():
                 for sletter in ['s', 'S']:
                     for eletter in ['e', 'E']:
                         curr = fletter+aletter+lletter+sletter+eletter
-                        yield ('bool-'+curr, oz.ozutil.string_to_bool, curr)
+                        assert(oz.ozutil.string_to_bool(curr) == False)
 
 def test_stb_yes():
     for yletter in ['y', 'Y']:
         for eletter in ['e', 'E']:
             for sletter in ['s', 'S']:
                 curr = yletter+eletter+sletter
-                yield ('bool-'+curr, oz.ozutil.string_to_bool, curr)
+                assert(oz.ozutil.string_to_bool(curr) == True)
 
 def test_stb_true():
     for tletter in ['t', 'T']:
@@ -202,7 +202,7 @@ def test_stb_true():
             for uletter in ['u', 'U']:
                 for eletter in ['e', 'E']:
                     curr = tletter+rletter+uletter+eletter
-                    yield ('bool-'+curr, oz.ozutil.string_to_bool, curr)
+                    assert(oz.ozutil.string_to_bool(curr) == True)
 
 def test_stb_none():
     with py.test.raises(Exception):
@@ -210,12 +210,13 @@ def test_stb_none():
 
 
 def test_stb_invalid():
-    if oz.ozutil.string_to_bool('foobar') is not None:
-        raise Exception("Expected None return from string_to_bool")
+    assert(oz.ozutil.string_to_bool('foobar') is None)
 
 # test oz.ozutil.generate_macaddress
 def test_genmac():
-    oz.ozutil.generate_macaddress()
+    mac = oz.ozutil.generate_macaddress()
+    assert(type(mac) == str)
+    assert(len(mac) == 17)
 
 # test oz.ozutil.mkdir_p
 def test_mkdir_p(tmpdir):
@@ -279,17 +280,18 @@ def test_copy_modify_empty_file(tmpdir):
     f.close()
     dst = os.path.join(str(tmpdir), 'dst')
     oz.ozutil.copy_modify_file(src, dst, sub)
+    assert(os.stat(dst).st_size == 0)
 
 def test_copy_modify_file(tmpdir):
     def sub(line):
         return line
     src = os.path.join(str(tmpdir), 'src')
-    f = open(src, 'w')
-    f.write("this is a line in the file\n")
-    f.write("this is another line in the file\n")
-    f.close()
+    with open(src, 'w') as f:
+        f.write("this is a line in the file\n")
+        f.write("this is another line in the file\n")
     dst = os.path.join(str(tmpdir), 'dst')
     oz.ozutil.copy_modify_file(src, dst, sub)
+    assert(os.stat(dst).st_size == 60)
 
 # test oz.ozutil.write_cpio
 def test_write_cpio_none_input():
@@ -347,102 +349,90 @@ def test_write_cpio_exception(tmpdir):
 
 def test_md5sum_regular(tmpdir):
     src = os.path.join(str(tmpdir), 'md5sum')
-    f = open(src, 'w')
-    f.write('# this is a comment line, followed by a blank line\n\n6e812e782e52b536c0307bb26b3c244e *Fedora-11-i386-DVD.iso\n')
-    f.close()
+    with open(src, 'w') as f:
+        f.write('# this is a comment line, followed by a blank line\n\n6e812e782e52b536c0307bb26b3c244e *Fedora-11-i386-DVD.iso\n')
 
     oz.ozutil.get_md5sum_from_file(src, 'Fedora-11-i386-DVD.iso')
 
 def test_sha1sum_regular(tmpdir):
     src = os.path.join(str(tmpdir), 'md5sum')
-    f = open(src, 'w')
-    f.write('6e812e782e52b536c0307bb26b3c244e1c42b644 *Fedora-11-i386-DVD.iso\n')
-    f.close()
+    with open(src, 'w') as f:
+        f.write('6e812e782e52b536c0307bb26b3c244e1c42b644 *Fedora-11-i386-DVD.iso\n')
 
     oz.ozutil.get_sha1sum_from_file(src, 'Fedora-11-i386-DVD.iso')
 
 def test_sha256sum_regular(tmpdir):
     src = os.path.join(str(tmpdir), 'md5sum')
-    f = open(src, 'w')
-    f.write('6e812e782e52b536c0307bb26b3c244e1c42b644235f5a4b242786b1ef375358 *Fedora-11-i386-DVD.iso\n')
-    f.close()
+    with open(src, 'w') as f:
+        f.write('6e812e782e52b536c0307bb26b3c244e1c42b644235f5a4b242786b1ef375358 *Fedora-11-i386-DVD.iso\n')
 
     oz.ozutil.get_sha256sum_from_file(src, 'Fedora-11-i386-DVD.iso')
 
 def test_md5sum_bsd(tmpdir):
     src = os.path.join(str(tmpdir), 'md5sum')
-    f = open(src, 'w')
-    f.write('MD5 (Fedora-11-i386-DVD.iso)=6e812e782e52b536c0307bb26b3c244e1c42b644235f5a4b242786b1ef375358\n')
-    f.close()
+    with open(src, 'w') as f:
+        f.write('MD5 (Fedora-11-i386-DVD.iso)=6e812e782e52b536c0307bb26b3c244e1c42b644235f5a4b242786b1ef375358\n')
 
     oz.ozutil.get_md5sum_from_file(src, 'Fedora-11-i386-DVD.iso')
 
 def test_md5sum_bsd_no_start_paren(tmpdir):
     src = os.path.join(str(tmpdir), 'md5sum')
-    f = open(src, 'w')
-    # if BSD is missing a paren, we don't raise an exception, just ignore and
-    # continue
-    f.write('MD5 Fedora-11-i386-DVD.iso)=6e812e782e52b536c0307bb26b3c244e1c42b644235f5a4b242786b1ef375358\n')
-    f.close()
+    with open(src, 'w') as f:
+        # if BSD is missing a paren, we don't raise an exception, just ignore and
+        # continue
+        f.write('MD5 Fedora-11-i386-DVD.iso)=6e812e782e52b536c0307bb26b3c244e1c42b644235f5a4b242786b1ef375358\n')
 
     oz.ozutil.get_md5sum_from_file(src, 'Fedora-11-i386-DVD.iso')
 
 def test_md5sum_bsd_no_end_paren(tmpdir):
     src = os.path.join(str(tmpdir), 'md5sum')
-    f = open(src, 'w')
-    # if BSD is missing a paren, we don't raise an exception, just ignore and
-    # continue
-    f.write('MD5 (Fedora-11-i386-DVD.iso=6e812e782e52b536c0307bb26b3c244e1c42b644235f5a4b242786b1ef375358\n')
-    f.close()
+    with open(src, 'w') as f:
+        # if BSD is missing a paren, we don't raise an exception, just ignore and
+        # continue
+        f.write('MD5 (Fedora-11-i386-DVD.iso=6e812e782e52b536c0307bb26b3c244e1c42b644235f5a4b242786b1ef375358\n')
 
     oz.ozutil.get_md5sum_from_file(src, 'Fedora-11-i386-DVD.iso')
 
 def test_md5sum_bsd_no_equal(tmpdir):
     src = os.path.join(str(tmpdir), 'md5sum')
-    f = open(src, 'w')
-    # if BSD is missing a paren, we don't raise an exception, just ignore and
-    # continue
-    f.write('MD5 (Fedora-11-i386-DVD.iso) 6e812e782e52b536c0307bb26b3c244e1c42b644235f5a4b242786b1ef375358\n')
-    f.close()
+    with open(src, 'w') as f:
+        # if BSD is missing a paren, we don't raise an exception, just ignore and
+        # continue
+        f.write('MD5 (Fedora-11-i386-DVD.iso) 6e812e782e52b536c0307bb26b3c244e1c42b644235f5a4b242786b1ef375358\n')
 
     oz.ozutil.get_md5sum_from_file(src, 'Fedora-11-i386-DVD.iso')
 
 def test_md5sum_regular_escaped(tmpdir):
     src = os.path.join(str(tmpdir), 'md5sum')
-    f = open(src, 'w')
-    f.write('\\6e812e782e52b536c0307bb26b3c244e *Fedora-11-i386-DVD.iso\n')
-    f.close()
+    with open(src, 'w') as f:
+        f.write('\\6e812e782e52b536c0307bb26b3c244e *Fedora-11-i386-DVD.iso\n')
 
     oz.ozutil.get_md5sum_from_file(src, 'Fedora-11-i386-DVD.iso')
 
 def test_md5sum_regular_too_short(tmpdir):
     src = os.path.join(str(tmpdir), 'md5sum')
-    f = open(src, 'w')
-    f.write('6e *F\n')
-    f.close()
+    with open(src, 'w') as f:
+        f.write('6e *F\n')
 
     oz.ozutil.get_md5sum_from_file(src, 'Fedora-11-i386-DVD.iso')
 
 def test_md5sum_regular_no_star(tmpdir):
     src = os.path.join(str(tmpdir), 'md5sum')
-    f = open(src, 'w')
-    f.write('6e812e782e52b536c0307bb26b3c244e Fedora-11-i386-DVD.iso\n')
-    f.close()
+    with open(src, 'w') as f:
+        f.write('6e812e782e52b536c0307bb26b3c244e Fedora-11-i386-DVD.iso\n')
 
     oz.ozutil.get_md5sum_from_file(src, 'Fedora-11-i386-DVD.iso')
 
 def test_md5sum_regular_no_newline(tmpdir):
     src = os.path.join(str(tmpdir), 'md5sum')
-    f = open(src, 'w')
-    f.write('6e812e782e52b536c0307bb26b3c244e *Fedora-11-i386-DVD.iso')
-    f.close()
+    with open(src, 'w') as f:
+        f.write('6e812e782e52b536c0307bb26b3c244e *Fedora-11-i386-DVD.iso')
 
     oz.ozutil.get_md5sum_from_file(src, 'Fedora-11-i386-DVD.iso')
 
 def test_md5sum_regular_no_space(tmpdir):
     src = os.path.join(str(tmpdir), 'md5sum')
-    f = open(src, 'w')
-    f.write('6e812e782e52b536c0307bb26b3c244e_*Fedora-11-i386-DVD.iso\n')
-    f.close()
+    with open(src, 'w') as f:
+        f.write('6e812e782e52b536c0307bb26b3c244e_*Fedora-11-i386-DVD.iso\n')
 
     oz.ozutil.get_md5sum_from_file(src, 'Fedora-11-i386-DVD.iso')
